@@ -200,12 +200,6 @@ TRIM_VIEW_ON = 0
 TRIM_VIEW_SINGLE = 1
 TRIM_VIEW_OFF = 2
 
-# Midbar layout
-MIDBAR_TC_LEFT = 0
-MIDBAR_TC_CENTER = 1
-MIDBAR_COMPONENTS_CENTERED = 2
-MIDBAR_TC_FREE = 3 # DEPRECATED, all layouts now have configurable buttons.
-
 # Windows mode
 SINGLE_WINDOW = 1
 TWO_WINDOWS = 2
@@ -334,6 +328,7 @@ PANEL_PLACEMENT_BOTTOM_ROW_RIGHT = 4
 PANEL_PLACEMENT_TOP_ROW_PROJECT_DEFAULT = 5
 PANEL_PLACEMENT_NOT_VISIBLE = 6
 PANEL_PLACEMENT_TWO_WINDOWS_MEDIA_PANEL_POS = 7
+PANEL_PLACEMENT_RIGHT_COLUMN = 8
 
 # Panels
 PANEL_MEDIA = 0
@@ -351,10 +346,75 @@ PANEL_FILTER_SELECT = 9
 KEYFRAME_LINEAR = 0
 KEYFRAME_SMOOTH = 1
 KEYFRAME_DISCRETE = 2
+KEYFRAME_SMOOTH_NATURAL = 3
+KEYFRAME_SMOOTH_TIGHT = 4
+KEYFRAME_SINUSOIDAL_IN = 5
+KEYFRAME_SINUSOIDAL_OUT = 6
+KEYFRAME_SINUSOIDAL_IN_OUT = 7
+KEYFRAME_QUADRATIC_IN = 8
+KEYFRAME_QUADRATIC_OUT = 9
+KEYFRAME_QUADRATIC_IN_OUT = 10
+KEYFRAME_CUBIC_IN = 11
+KEYFRAME_CUBIC_OUT = 12
+KEYFRAME_CUBIC_IN_OUT = 13
+KEYFRAME_QUARTIC_IN = 14
+KEYFRAME_QUARTIC_OUT = 15
+KEYFRAME_QUARTIC_IN_OUT = 16
+KEYFRAME_QUINTIC_IN = 17
+KEYFRAME_QUINTIC_OUT = 18
+KEYFRAME_QUINTIC_IN_OUT = 19
+KEYFRAME_EXPONENTIAL_IN = 20
+KEYFRAME_EXPONENTIAL_OUT = 21
+KEYFRAME_EXPONENTIAL_IN_OUT = 22
+KEYFRAME_CIRCULAR_IN = 23
+KEYFRAME_CIRCULAR_OUT = 24
+KEYFRAME_CIRCULAR_IN_OUT = 25
+KEYFRAME_BACK_IN = 26
+KEYFRAME_BACK_OUT = 27
+KEYFRAME_BACK_IN_OUT = 28
+KEYFRAME_ELASTIC_IN = 29
+KEYFRAME_ELASTIC_OUT = 30
+KEYFRAME_ELASTIC_IN_OUT = 31
+KEYFRAME_BOUNCE_IN = 32
+KEYFRAME_BOUNCE_OUT = 33
+KEYFRAME_BOUNCE_IN_OUT = 34
 
+# MLT Keyframe type identifiers in equals signs"
 KEYFRAME_LINEAR_EQUALS_STR = "="
 KEYFRAME_SMOOTH_EQUALS_STR = "~="
 KEYFRAME_DISCRETE_EQUALS_STR = "|="
+KEYFRAME_SMOOTH_NATURAL_EQUALS_STR = "$="
+KEYFRAME_SMOOTH_TIGHT_EQUALS_STR = "-="
+KEYFRAME_SINUSOIDAL_IN_EQUALS_STR = "a="
+KEYFRAME_SINUSOIDAL_OUT_EQUALS_STR = "b="
+KEYFRAME_SINUSOIDAL_IN_OUT_EQUALS_STR = "c="
+KEYFRAME_QUADRATIC_IN_EQUALS_STR = "d="
+KEYFRAME_QUADRATIC_OUT_EQUALS_STR = "e="
+KEYFRAME_QUADRATIC_IN_OUT_EQUALS_STR = "f="
+KEYFRAME_CUBIC_IN_EQUALS_STR = "g="
+KEYFRAME_CUBIC_OUT_EQUALS_STR = "h="
+KEYFRAME_CUBIC_IN_OUT_EQUALS_STR = "i="
+KEYFRAME_QUARTIC_IN_EQUALS_STR = "j="
+KEYFRAME_QUARTIC_OUT_EQUALS_STR = "k="
+KEYFRAME_QUARTIC_IN_OUT_EQUALS_STR = "l="
+KEYFRAME_QUINTIC_IN_EQUALS_STR = "m="
+KEYFRAME_QUINTIC_OUT_EQUALS_STR = "n="
+KEYFRAME_QUINTIC_IN_OUT_EQUALS_STR = "o="
+KEYFRAME_EXPONENTIAL_IN_EQUALS_STR = "p="
+KEYFRAME_EXPONENTIAL_OUT_EQUALS_STR = "q="
+KEYFRAME_EXPONENTIAL_IN_OUT_EQUALS_STR = "r=" 
+KEYFRAME_CIRCULAR_IN_EQUALS_STR = "s="
+KEYFRAME_CIRCULAR_OUT_EQUALS_STR = "t="
+KEYFRAME_CIRCULAR_IN_OUT_EQUALS_STR = "u="
+KEYFRAME_BACK_IN_EQUALS_STR = "v="
+KEYFRAME_BACK_OUT_EQUALS_STR = "w="
+KEYFRAME_BACK_IN_OUT_EQUALS_STR = "x="
+KEYFRAME_ELASTIC_IN_EQUALS_STR = "y="
+KEYFRAME_ELASTIC_OUT_EQUALS_STR = "z="
+KEYFRAME_ELASTIC_IN_OUT_EQUALS_STR = "A="
+KEYFRAME_BOUNCE_IN_EQUALS_STR = "B="
+KEYFRAME_BOUNCE_OUT_EQUALS_STR = "C="
+KEYFRAME_BOUNCE_IN_OUT_EQUALS_STR = "D="
 
 # Multi edit panel display options.
 EDIT_MULTI_EMPTY = "edit_multi_empty"
