@@ -37,6 +37,7 @@ import time
 
 import appconsts
 import callbackbridge
+import ccrutils
 import dialogutils
 import edit
 import editorstate
@@ -65,7 +66,7 @@ This module creates <ConatainerClipType>Actions wrapper objects for container cl
 all actions on container clips data.
 
 Objects of class containerclips.ContainerData are persistent data for container clips, 
-objects in this module created and discarded as needed.
+objects in this module are created and discarded as needed.
 """
 
 FULL_RENDER = 0
@@ -78,6 +79,7 @@ GMIC_TYPE_ICON = None
 MLT_XML_TYPE_ICON = None
 BLENDER_TYPE_ICON = None # Deprecated
 FLUXITY_TYPE_ICON = None
+SEQUENCE_LINK_TYPE_ICON = None
 
 NEWLINE = '\n'
 
@@ -90,11 +92,13 @@ def get_action_object(container_data):
          return MLTXMLContainerActions(container_data)
     elif container_data.container_type == appconsts.CONTAINER_CLIP_FLUXITY:
          return FluxityContainerActions(container_data)
+    elif container_data.container_type == appconsts.CONTAINER_CLIP_SEQUENCE_LINK:
+         return SequenceLinkContainerActions(container_data)
          
 # ------------------------------------------------------------ thumbnail creation helpers
 def _get_type_icon(container_type):
-    # TODO: When we get third move this into action objects.
-    global GMIC_TYPE_ICON, MLT_XML_TYPE_ICON, FLUXITY_TYPE_ICON
+    # TODO: We should move this into action objects.
+    global GMIC_TYPE_ICON, MLT_XML_TYPE_ICON, FLUXITY_TYPE_ICON, SEQUENCE_LINK_TYPE_ICON
     
     if GMIC_TYPE_ICON == None:
         GMIC_TYPE_ICON = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "container_clip_gmic.png")
@@ -102,6 +106,8 @@ def _get_type_icon(container_type):
         MLT_XML_TYPE_ICON = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "container_clip_mlt_xml.png")
     if FLUXITY_TYPE_ICON == None:
         FLUXITY_TYPE_ICON = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "container_clip_fluxity.png")
+    if SEQUENCE_LINK_TYPE_ICON == None:
+        SEQUENCE_LINK_TYPE_ICON = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "container_sequence_link_icon.png")
         
     if container_type == appconsts.CONTAINER_CLIP_GMIC:
         return GMIC_TYPE_ICON
@@ -109,7 +115,9 @@ def _get_type_icon(container_type):
         return MLT_XML_TYPE_ICON
     elif container_type == appconsts.CONTAINER_CLIP_FLUXITY:  
         return FLUXITY_TYPE_ICON
-        
+    elif container_type == appconsts.CONTAINER_CLIP_SEQUENCE_LINK:
+        return SEQUENCE_LINK_TYPE_ICON
+
 def _write_thumbnail_image(profile, file_path, action_object):
     """
     Writes thumbnail image from file producer
@@ -158,7 +166,8 @@ class AbstractContainerActionObject:
         self.container_data = container_data
         self.render_type = -1 # to be set in methods below
         self.do_filters_clone = False
-        
+        self.video_file_name = None
+
     def create_data_dirs_if_needed(self):
         session_folder = self.get_session_dir()
         clip_frames_folder = session_folder + appconsts.CC_CLIP_FRAMES_DIR
@@ -170,6 +179,25 @@ class AbstractContainerActionObject:
         if not os.path.exists(rendered_frames_folder):
             os.mkdir(rendered_frames_folder)
 
+    def clone_container_data_files(self, orig_clip):
+        if orig_clip.container_data.rendered_media != None:
+            orig_clip_action = get_action_object(orig_clip.container_data)
+            src_dir = orig_clip_action.get_session_dir()
+            dst_dir = self.get_session_dir()
+            
+            shutil.copytree(src_dir, dst_dir)
+            
+            # Fix 'rendered_media' path.
+            rendered_path = None
+            for f in os.listdir(orig_clip_action.get_session_dir()):
+                if os.path.basename(f).split()[0] == "caintainer_clip":
+                    rendered_path = f
+
+            self.container_data.rendered_media = rendered_path
+
+        # This is only used between containers in same project so not cloning 
+        # file pointed to by 'container_data.unrendered_media' is acceptable.
+
     def validate_program(self):
         print("AbstractContainerActionObject.validate_program() not impl")
 
@@ -180,7 +208,7 @@ class AbstractContainerActionObject:
         job_proxy = self.get_launch_job_proxy()
         jobs.add_job(job_proxy)
         
-        # Render starts on callback from jobs.py
+        # Render starts on callback from jobs.py self._launch_render()
         
     def render_clip_length_media(self, clip):
         self.render_type = CLIP_LENGTH_RENDER
@@ -290,9 +318,13 @@ class AbstractContainerActionObject:
 
     def get_rendered_video_clip_path(self):
         if self.container_data.render_data.save_internally == True:
-            resource_path = self.get_session_dir() +  "/" + appconsts.CONTAINER_CLIP_VIDEO_CLIP_NAME + self.container_data.render_data.file_extension
+            if self.video_file_name == None:
+                file_name = appconsts.CONTAINER_CLIP_VIDEO_CLIP_NAME
+            else:
+                file_name = self.video_file_name
+            resource_path = self.get_session_dir() + "/" + appconsts.CONTAINER_CLIP_VIDEO_CLIP_NAME + self.container_data.render_data.file_extension
         else:
-            resource_path = self.container_data.render_data.render_dir +  "/" + self.container_data.render_data.file_name + self.container_data.render_data.file_extension
+            resource_path = self.container_data.render_data.render_dir + "/" + self.container_data.render_data.file_name + self.container_data.render_data.file_extension
     
         return resource_path
     
@@ -310,7 +342,7 @@ class AbstractContainerActionObject:
     def abort_render(self):
         print("AbstractContainerActionObject.abort_render not impl")
 
-    def create_producer_and_do_update_edit(self, unused_data):
+    def create_producer_and_do_update_edit(self, unused_data, video_file_name=None):
 
         # Using frame sequence as clip
         if  self.container_data.render_data.do_video_render == False:
@@ -362,7 +394,7 @@ class AbstractContainerActionObject:
         # Create default render data if not available, we need to know profile to do this.
         if self.container_data.render_data == None:
             self.container_data.render_data = toolsencoding.create_container_clip_default_render_data_object(current_sequence().profile)
-            
+    
         encoding_panel = toolsencoding.get_encoding_panel(self.container_data.render_data, True)
         if show_render_buttons == True:
             render_combo = Gtk.ComboBoxText()
@@ -410,7 +442,36 @@ class AbstractContainerActionObject:
                     self.external_encoding_callback(self.render_combo)
                     
         dialog.destroy()
+
+    def set_project_default_video_endoding(self):
+        current_profile_index = mltprofiles.get_profile_index_for_profile(current_sequence().profile)
+        # These need to re-initialized always when using this module.
+        toolsencoding.create_widgets(current_profile_index, True, True)
+
+        encoding_panel = toolsencoding.get_default_encoding_setting_panel(PROJECT().container_default_encoding)
+        encoding_panel.set_margin_right(150)
+        align = dialogutils.get_default_alignment(encoding_panel)
         
+        dialog = Gtk.Dialog(_("Set Container Default Encoding"),
+                            gui.editor_window.window,
+                            Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                            (_("Cancel"), Gtk.ResponseType.REJECT,
+                             (_("Set Default Encoding")), Gtk.ResponseType.ACCEPT))
+        dialog.vbox.pack_start(align, True, True, 0)
+        dialogutils.set_outer_margins(dialog.vbox)
+        dialog.set_resizable(False)
+        dialog.connect('response', self.default_encode_settings_callback)
+        dialog.show_all()
+
+    def default_encode_settings_callback(self, dialog, response_id):
+        if response_id == Gtk.ResponseType.ACCEPT:
+            encoding_panel = toolsencoding.widgets.encoding_panel
+            encoding_option_index = encoding_panel.encoding_selector.get_selected_encoding_index()
+            quality_option_index = encoding_panel.quality_selector.widget.get_active()
+            default_encoding = (encoding_option_index, quality_option_index)
+            PROJECT().container_default_encoding = default_encoding
+        dialog.destroy()
+
     def clone_clip(self, old_clip):
         new_container_data = copy.deepcopy(old_clip.container_data)
         new_container_data.generate_clip_id()
@@ -463,6 +524,7 @@ class AbstractContainerActionObject:
     def create_image_surface(self, icon_path):
         return _create_image_surface(icon_path)
 
+
 class GMicContainerActions(AbstractContainerActionObject):
 
     def __init__(self, container_data):
@@ -545,7 +607,9 @@ class GMicContainerActions(AbstractContainerActionObject):
         for arg in args:
             command_list.append(arg)
 
-        subprocess.Popen(command_list)
+        # We need to wait() in thread.
+        command_list_runner = ProcessCommandListRunner(command_list)
+        command_list_runner.start()
         
     def update_render_status(self):
         GLib.idle_add(self._do_update_render_status)
@@ -617,6 +681,7 @@ class GMicContainerActions(AbstractContainerActionObject):
         cr.set_source_surface(type_icon, 1, 30)
         cr.set_operator (cairo.OPERATOR_OVERLAY)
         cr.paint_with_alpha(0.5)
+        surface.write_to_png(icon_path)
         return (surface, length, icon_path)
 
 
@@ -727,7 +792,6 @@ class FluxityContainerActions(AbstractContainerActionObject):
             if self.plugin_create_render_complete_callback == None:
                 # Completed render for timeline container clip update is handled here.
                 GLib.idle_add(self.plugin_tline_render_comlete)
-                GLib.idle_add(self.create_producer_and_do_update_edit, None)
             else:
                 # Completed render for adding Generator plugin as rendered video clip is handled here. 
                 if self.container_data.render_data.do_video_render == False:
@@ -905,10 +969,10 @@ class MLTXMLContainerActions(AbstractContainerActionObject):
 
         args = ("session_id:" + self.get_container_program_id(),
                 "parent_folder:" + str(self.parent_folder),
-                "clip_path:" + str(self.container_data.unrendered_media),
                 "range_in:" + str(range_in),
                 "range_out:"+ str(range_out),
                 "profile_desc:" + PROJECT().profile.description().replace(" ", "_"),
+                "video_file_name:" + mltxmlheadless.NO_RENDER_TARGET_FILE_SPECIFIED,
                 "xml_file_path:" + str(self.container_data.unrendered_media))
 
         # Create command list and launch process.
@@ -917,7 +981,9 @@ class MLTXMLContainerActions(AbstractContainerActionObject):
         for arg in args:
             command_list.append(arg)
 
-        subprocess.Popen(command_list)
+        # We need to wait() in thread.
+        command_list_runner = ProcessCommandListRunner(command_list)
+        command_list_runner.start()
 
     def update_render_status(self):
         GLib.idle_add(self._do_update_render_status)
@@ -957,6 +1023,123 @@ class MLTXMLContainerActions(AbstractContainerActionObject):
         mltxmlheadless.abort_render(self.parent_folder, self.get_container_program_id())
 
 
+class SequenceLinkContainerActions(AbstractContainerActionObject):
+
+    def __init__(self, container_data):
+        AbstractContainerActionObject.__init__(self, container_data)
+        self.do_filters_clone = True
+        self.parent_folder = userfolders.get_container_clips_dir()
+        
+    def validate_program(self):
+        # These are created by application and are quaranteed to be valid.
+        # This method is not even called.
+        return True
+        
+    def get_job_proxy(self):
+        job_proxy = jobs.JobProxy(self.get_container_program_id(), self)
+        job_proxy.type = jobs.CONTAINER_CLIP_RENDER_MLT_XML
+        return job_proxy
+
+    def get_job_name(self):
+        return self.container_data.get_unrendered_media_name()
+
+    def _launch_render(self, clip, range_in, range_out, clip_start_offset):
+        self.create_data_dirs_if_needed()
+        self.render_range_in = range_in
+        self.render_range_out = range_out
+        self.clip_start_offset = clip_start_offset
+ 
+        mltxmlheadless.clear_flag_files(self.parent_folder, self.get_container_program_id())
+    
+        # We need data to be available for render process, 
+        # create video_render_data object with default values if not available.
+        if self.container_data.render_data == None:
+            self.container_data.render_data = toolsencoding.create_container_clip_default_render_data_object(current_sequence().profile)
+            
+        mltxmlheadless.set_render_data(self.parent_folder, self.get_container_program_id(), self.container_data.render_data)
+
+        self.video_file_name = appconsts.CONTAINER_CLIP_VIDEO_CLIP_NAME
+        session_folder = ccrutils.get_session_folder(self.parent_folder, self.get_container_program_id())
+        number = 2
+        retry = True
+        while retry == True:
+            file_path = session_folder + "/" + self.video_file_name + self.container_data.render_data.file_extension
+            if os.path.isfile(file_path) == False:
+                retry = False
+            else:
+                self.video_file_name = appconsts.CONTAINER_CLIP_VIDEO_CLIP_NAME + str(number) 
+                number += 1
+
+        job_msg = self.get_job_queue_message()
+        job_msg.text = _("Render Starting...")
+        job_msg.status = jobs.RENDERING
+        jobs.update_job_queue(job_msg)
+
+        args = ("session_id:" + self.get_container_program_id(),
+                "parent_folder:" + str(self.parent_folder),
+                "range_in:" + str(range_in),
+                "range_out:"+ str(range_out),
+                "profile_desc:" + PROJECT().profile.description().replace(" ", "_"),
+                "video_file_name:" + str(self.video_file_name),
+                "xml_file_path:" + str(self.container_data.unrendered_media))
+
+        # Create command list and launch process.
+        command_list = [sys.executable]
+        command_list.append(respaths.LAUNCH_DIR + "flowblademltxmlheadless")
+        for arg in args:
+            command_list.append(arg)
+
+        # We need to wait() in thread.
+        command_list_runner = ProcessCommandListRunner(command_list)
+        command_list_runner.start()
+
+    def update_render_status(self):
+        GLib.idle_add(self._do_update_render_status)
+            
+    def _do_update_render_status(self):
+                    
+        if mltxmlheadless.session_render_complete(self.parent_folder, self.get_container_program_id()) == True:
+            #self.remove_as_status_polling_object()
+
+            job_msg = self.get_completed_job_message()
+            jobs.update_job_queue(job_msg)
+            
+            GLib.idle_add(self.create_producer_and_do_update_edit, None)
+                
+        else:
+            status = mltxmlheadless.get_session_status(self.parent_folder, self.get_container_program_id())
+
+            if status != None:
+                fraction, elapsed = status
+
+                if self.container_data.render_data.do_video_render == True:
+                    msg = _("Video for Selection Clip: ") + self.clip.name 
+
+                job_msg = self.get_job_queue_message()
+                job_msg.progress = float(fraction)
+                job_msg.elapsed = float(elapsed)
+                job_msg.text = msg
+                
+                jobs.update_job_queue(job_msg)
+            else:
+                pass # This can happen sometimes before gmicheadless.py has written a status message, we just do nothing here.
+
+    def get_rendered_thumbnail(self):
+        surface, length, icon_path = self.create_icon()
+        return surface
+        
+    def create_icon(self):
+        icon_path, length, info = _write_thumbnail_image(PROJECT().profile, self.container_data.unrendered_media, self)
+        cr, surface = _create_image_surface(icon_path)
+        type_icon = _get_type_icon(appconsts.CONTAINER_CLIP_SEQUENCE_LINK)
+        cr.set_source_surface(type_icon, 0, 0)
+        cr.paint()
+        surface.write_to_png(icon_path)
+        return (surface, length, icon_path)
+
+    def abort_render(self):
+        mltxmlheadless.abort_render(self.parent_folder, self.get_container_program_id())
+
 # -------------------------------------------------------------- creating unrendered clip
 def create_unrendered_clip(length, image_file, data, callback, window_text):
     unrendered_creation_thread = UnrenderedCreationThread(length, image_file, data, callback, window_text)
@@ -1031,5 +1214,15 @@ class CommandLauncherThread(threading.Thread):
         for arg in self.args:
             command_list.append(arg)
 
-        subprocess.Popen(command_list)
+        process = subprocess.Popen(command_list)
+        process.wait()
+
+class ProcessCommandListRunner(threading.Thread):
+    def __init__(self, command_list):
+        threading.Thread.__init__(self)
+        self.command_list = command_list
+        
+    def run(self):
+        process = subprocess.Popen(self.command_list)
+        process.wait()
         
\ No newline at end of file
