@@ -470,8 +470,6 @@ def get_media_plugin_length(callback, data):
     dialog.connect('response', callback, data, length_spin, name_entry)
     dialog.show_all()
 
-
-
 def export_xml_dialog(callback, project_name):
     _export_file_name_dialog(callback, project_name, _("Export Project as XML to"))
 
@@ -600,8 +598,8 @@ def about_dialog(parent_window):
     # Application tab
     img = Gtk.Image.new_from_file(respaths.IMAGE_PATH + "flowbladeappicon.png")
     flow_label = Gtk.Label(label="Flowblade Movie Editor")
-    ver_label = Gtk.Label(label="2.20")
-    janne_label = Gtk.Label(label="Copyright 2024 Janne Liljeblad and contributors.")
+    ver_label = Gtk.Label(label="2.22.1")
+    janne_label = Gtk.Label(label="Copyright 2025 Janne Liljeblad and contributors.")
     page_label = Gtk.Label(label=_("Project page:") + " " + "<a href=\"https://github.com/jliljebl/flowblade\">https://github.com/jliljebl/flowblade</a>")
     page_label.set_use_markup(True)
     flow_label.modify_font(Pango.FontDescription("sans bold 14"))
