@@ -34,6 +34,7 @@ from gi.repository import Gtk
 import appconsts
 import cairo
 import cairoarea
+import dialogutils
 from editorstate import PROJECT
 import guiutils
 import guicomponents
@@ -1209,12 +1210,16 @@ class AnalyzeStabilizeFilterEditor:
         clip_path = self.editable_properties[0].clip.path
         accuracy_prop = [ep for ep in self.editable_properties if ep.name == "accuracy"][0]
         shakiness_prop = [ep for ep in self.editable_properties if ep.name == "shakiness"][0]
+        smoothing_prop = [ep for ep in self.editable_properties if ep.name == "smoothing"][0]
+        zoom_prop = [ep for ep in self.editable_properties if ep.name == "zoom"][0]
         
         args = ("session_id:" + str(session_id),
                 "profile_desc:" + str(profile_desc),
                 "clip_path:" + str(clip_path),
                 "shakiness:" + str(shakiness_prop.value),
-                "accuracy:" + str(accuracy_prop.value))
+                "accuracy:" + str(accuracy_prop.value),
+                "smoothing:" + str(smoothing_prop.value),
+                "zoom:" + str(zoom_prop.value))
 
         job = jobs.StablizeDataRenderJobQueueObject(session_id, self.filter, self.editable_properties, self, args)
         job.add_to_queue()
@@ -1229,8 +1234,8 @@ class AnalyzeStabilizeFilterEditor:
 class AnalyzeMotionTrackingFilterEditor:
     def __init__(self, filter, editable_properties):
         self.filter = filter
-        # We need to turn this because otherwise filter keeps attemting to 
-        # analyze tracking continuosly. We want analyzing to happen in the 
+        # We need to turn this because otherwise filter keeps attempting to 
+        # analyze tracking continuously. We want analyzing to happen in the 
         # dedicated process and only results be displayed.
         # ...aaand this only has effect if we have some results?
         self.filter.mlt_filter.set("analyze", "0")
@@ -1324,7 +1329,7 @@ class AnalyzeMotionTrackingFilterEditor:
         if len(data_label) == 0:
             data_label = self.get_default_data_label()
         
-        job = jobs.MotionTrackingDataRenderJobQueueObject(session_id, self.filter, self.editable_properties, self, args, data_label)
+        job = jobs.TrackingDataRenderJobQueueObject(session_id, self.filter, self.editable_properties, self, args, data_label)
         job.add_to_queue()
 
     def analysis_complete(self, final_label, data_file_path):
@@ -1345,7 +1350,7 @@ class AnalyzeMotionTrackingFilterEditor:
             self.box_gui_editor.geom_kf_edit.widget.queue_draw()
             self.set_buttons_state()
         except Exception as e :
-            # GUI might havenn destoyed during rendering.
+            # GUI might havenn destroyed during rendering.
             print(e)
 
     def clear_button_clicked(self, button):
@@ -1374,16 +1379,21 @@ class ApplyMotionTrackingFilterEditor:
         self.non_mlt_editors = non_mlt_editors
         self.non_mlt_properties = non_mlt_properties
 
-        select_label = Gtk.Label(label=_("Select Motion Tracking Data:"))
-        select_label.set_margin_right(4)
+        self.select_label = Gtk.Label(label=_("Select Motion Tracking Data:"))
+        self.select_label.set_margin_right(4)
 
         selected_tracking_data = [ep for ep in self.non_mlt_properties if ep.name == "selected_tracking_data"][0].value
         self.data_select_keys, self.data_select_combo = motiontracking.get_tracking_data_select_combo(_("No Tracking Data Available"), selected_tracking_data)
 
-        hbox1 = Gtk.HBox()
-        hbox1.pack_start(select_label, False, False, 0) 
-        hbox1.pack_start(self.data_select_combo, True, True, 0)
-        hbox1.set_margin_bottom(24)
+        self.delete_button = Gtk.Button(label=_("Delete"))
+        self.delete_button.connect("clicked", self.delete_data)
+        self.delete_button.set_margin_left(12)
+    
+        self.hbox1 = Gtk.HBox()
+        self.hbox1.pack_start(self.select_label, False, False, 0) 
+        self.hbox1.pack_start(self.data_select_combo, True, True, 0)
+        self.hbox1.pack_start(self.delete_button, False, False, 0) 
+        self.hbox1.set_margin_bottom(24)
 
         self.info_label = Gtk.Label("<small>No Tracking Data Applied</small>")
         last_applied_date_str = [ep for ep in self.non_mlt_properties if ep.name == "last_applied_tracking_data"][0].value
@@ -1391,11 +1401,12 @@ class ApplyMotionTrackingFilterEditor:
             self.show_last_applied_date(last_applied_date_str)
         self.info_label.set_use_markup(True)
         self.info_label.set_margin_right(4)
-
+        
         self.button = Gtk.Button(label=_("Apply Motion Tracking Data"))
         self.button.connect("clicked", self.apply_tracking)
 
         hbox2 = Gtk.HBox()
+        hbox2.pack_start(self.delete_button, False, False, 0)
         hbox2.pack_start(Gtk.Label(), True, True, 0) 
         hbox2.pack_start(self.info_label, False, False, 0) 
         hbox2.pack_start(self.button, False, False, 0)
@@ -1403,7 +1414,7 @@ class ApplyMotionTrackingFilterEditor:
         hbox2.set_margin_bottom(24)
         
         self.widget = Gtk.VBox()
-        self.widget.pack_start(hbox1, False, False, 0)
+        self.widget.pack_start(self.hbox1, False, False, 0)
         for row in self.non_mlt_editors:
             self.widget.pack_start(row, False, False, 0)
         self.widget.pack_start(hbox2, False, False, 0)
@@ -1415,14 +1426,14 @@ class ApplyMotionTrackingFilterEditor:
         interpretation = [ep for ep in self.non_mlt_properties if ep.name == "interpretation"][0].value
         size = [ep for ep in self.non_mlt_properties if ep.name == "size"][0].value
         clip_in = self.editable_properties[0].clip.clip_in
-        
+
         info = utils.get_file_producer_info(self.editable_properties[0].clip)
         source_w = int(info["width"])
         source_h = int(info["height"])
         if self.editable_properties[0].clip.media_type == appconsts.IMAGE:
             graphic_img = Image.open(self.editable_properties[0].clip.path)
             source_w, source_h = graphic_img.size
-            
+
         motiontracking.apply_tracking(  tracking_data_id, self.filter, self.editable_properties, 
                                         int(float(xoff)), int(float(yoff)), interpretation, size, clip_in,
                                         source_w, source_h)
@@ -1440,6 +1451,47 @@ class ApplyMotionTrackingFilterEditor:
         self.info_label.set_use_markup(True)
         self.info_label.queue_draw()
 
+    def delete_data(self, button):
+        used_data = motiontracking.get_used_motion_tracking_data()
+        tracking_data_id = self.data_select_keys[self.data_select_combo.get_active()]
+        
+        if tracking_data_id in used_data:
+            self.confirm_delete()
+        else:
+            self.delete_selected()
+
+    def confirm_delete(self):
+        title = _("Confirm Motion Tracking Data Delete")
+        text = Gtk.Label(label=_("Current selected motion tracking data was applied somewhere in the project.\n\nDelete anyway?"))
+        panel = guiutils.get_left_justified_box([text])
+        accept_text = _("Delete")
+        dialogutils.panel_ok_cancel_dialog(title, panel, accept_text, self.delete_dialog_callback)
+
+    def delete_dialog_callback(self, dialog, response_id):
+        dialog.destroy()
+        if response_id == Gtk.ResponseType.ACCEPT:
+            self.delete_selected()
+
+    def delete_selected(self):
+        tracking_data_id = self.data_select_keys[self.data_select_combo.get_active()]
+        if tracking_data_id == None:
+            return # no tracking data exists.
+
+        PROJECT().delete_tracking_data(tracking_data_id)
+
+        children = self.hbox1.get_children()
+        for child in children:
+            self.hbox1.remove(child)
+
+        self.data_select_keys, self.data_select_combo = motiontracking.get_tracking_data_select_combo(_("No Tracking Data Available"), -1)
+        self.data_select_combo.show() 
+
+        self.hbox1.pack_start(self.select_label, False, False, 0) 
+        self.hbox1.pack_start(self.data_select_combo, True, True, 0)
+        self.hbox1.pack_start(self.delete_button, False, False, 0) 
+        
+        self.widget.queue_draw() 
+            
 
 class FilterMaskApplyMotionTrackingEditor:
     def __init__(self, filter, editable_properties, non_mlt_editors, non_mlt_properties):
@@ -1448,16 +1500,21 @@ class FilterMaskApplyMotionTrackingEditor:
         self.non_mlt_properties = non_mlt_properties
         self.non_mlt_editors = non_mlt_editors
         
-        select_label = Gtk.Label(label=_("Select Motion Tracking Data:"))
-        select_label.set_margin_right(4)
+        self.select_label = Gtk.Label(label=_("Select Motion Tracking Data:"))
+        self.select_label.set_margin_right(4)
 
         selected_tracking_data = [ep for ep in self.non_mlt_properties if ep.name == "selected_tracking_data"][0].value
         self.data_select_keys, self.data_select_combo = motiontracking.get_tracking_data_select_combo(_("No Tracking Data Available"), selected_tracking_data)
 
-        hbox1 = Gtk.HBox()
-        hbox1.pack_start(select_label, False, False, 0) 
-        hbox1.pack_start(self.data_select_combo, True, True, 0)
-        hbox1.set_margin_bottom(24)
+        self.delete_button = Gtk.Button(label=_("Delete"))
+        self.delete_button.connect("clicked", self.delete_data)
+        self.delete_button.set_margin_left(12)
+        
+        self.hbox1 = Gtk.HBox()
+        self.hbox1.pack_start(self.select_label, False, False, 0) 
+        self.hbox1.pack_start(self.data_select_combo, True, True, 0)
+        self.hbox1.pack_start(self.delete_button, False, False, 0) 
+        self.hbox1.set_margin_bottom(24)
 
         self.info_label = Gtk.Label("<small>No Tracking Data Applied</small>")
         last_applied_date_str = [ep for ep in self.non_mlt_properties if ep.name == "last_applied_tracking_data"][0].value
@@ -1469,18 +1526,18 @@ class FilterMaskApplyMotionTrackingEditor:
         self.button = Gtk.Button(label=_("Apply Motion Tracking Data"))
         self.button.connect("clicked", self.apply_tracking)
 
-        hbox2 = Gtk.HBox()
-        hbox2.pack_start(Gtk.Label(), True, True, 0) 
-        hbox2.pack_start(self.info_label, False, False, 0) 
-        hbox2.pack_start(self.button, False, False, 0)
-        hbox2.set_margin_top(24)
-        hbox2.set_margin_bottom(24)
+        self.hbox2 = Gtk.HBox()
+        self.hbox2.pack_start(Gtk.Label(), True, True, 0) 
+        self.hbox2.pack_start(self.info_label, False, False, 0) 
+        self.hbox2.pack_start(self.button, False, False, 0)
+        self.hbox2.set_margin_top(24)
+        self.hbox2.set_margin_bottom(24)
         
         self.widget = Gtk.VBox()
-        self.widget.pack_start(hbox1, False, False, 0)
+        self.widget.pack_start(self.hbox1, False, False, 0)
         for row in self.non_mlt_editors:
             self.widget.pack_start(row, False, False, 0)
-        self.widget.pack_start(hbox2, False, False, 0)
+        self.widget.pack_start(self.hbox2, False, False, 0)
 
     def apply_tracking(self, button):
         tracking_data_id = self.data_select_keys[self.data_select_combo.get_active()]
@@ -1502,4 +1559,45 @@ class FilterMaskApplyMotionTrackingEditor:
     def show_last_applied_date(self, date_str):
         self.info_label.set_text("<small>" + _("Last applied ") + date_str + "</small>")
         self.info_label.set_use_markup(True)
-        self.info_label.queue_draw()
\ No newline at end of file
+        self.info_label.queue_draw()
+
+    def delete_data(self, button):
+        used_data = motiontracking.get_used_motion_tracking_data()
+        tracking_data_id = self.data_select_keys[self.data_select_combo.get_active()]
+        
+        if tracking_data_id in used_data:
+            self.confirm_delete()
+        else:
+            self.delete_selected()
+
+    def confirm_delete(self):
+        title = _("Confirm Motion Tracking Data Delete")
+        text = Gtk.Label(label=_("Current selected motion tracking data was applied somewhere in the project.\n\nDelete anyway?"))
+        panel = guiutils.get_left_justified_box([text])
+        accept_text = _("Delete")
+        dialogutils.panel_ok_cancel_dialog(title, panel, accept_text, self.delete_dialog_callback)
+
+    def delete_dialog_callback(self, dialog, response_id):
+        dialog.destroy()
+        if response_id == Gtk.ResponseType.ACCEPT:
+            self.delete_selected()
+
+    def delete_selected(self):
+        tracking_data_id = self.data_select_keys[self.data_select_combo.get_active()]
+        if tracking_data_id == None:
+            return # no tracking data exists.
+
+        PROJECT().delete_tracking_data(tracking_data_id)
+
+        children = self.hbox1.get_children()
+        for child in children:
+            self.hbox1.remove(child)
+
+        self.data_select_keys, self.data_select_combo = motiontracking.get_tracking_data_select_combo(_("No Tracking Data Available"), -1)
+        self.data_select_combo.show() 
+
+        self.hbox1.pack_start(self.select_label, False, False, 0) 
+        self.hbox1.pack_start(self.data_select_combo, True, True, 0)
+        self.hbox1.pack_start(self.delete_button, False, False, 0) 
+
+        self.widget.queue_draw()
