@@ -46,11 +46,10 @@ BUTTON_NOT_SENSITIVE_GRAD_STOPS = [(1, 0.9, 0.9, 0.9, 0.7),
 
 CORNER_DIVIDER = 5
 
-# Aug-2019 - SvdB - BB
-MB_BUTTONS_WIDTH = [317,634]
-MB_BUTTONS_HEIGHT = [23,60]
-MB_BUTTON_HEIGHT = [22,44]
-MB_BUTTON_WIDTH = [30,60]
+MB_BUTTONS_WIDTH = [200]
+MB_BUTTONS_HEIGHT = [23]
+MB_BUTTON_HEIGHT = [22]
+MB_BUTTON_WIDTH = [30]
 MB_BUTTON_Y = 4
 MB_BUTTON_IMAGE_Y = 6
 
@@ -305,9 +304,6 @@ class PlayerButtons(AbstractGlassButtons):
         size_adj = 1
         prefs = editorpersistance.prefs
 
-        if guiutils.double_icon_size():
-           size_ind = 1
-           size_adj = 2
         AbstractGlassButtons.__init__(self, MB_BUTTON_WIDTH[size_ind], MB_BUTTON_HEIGHT[size_ind], MB_BUTTON_Y, MB_BUTTONS_WIDTH[size_ind], MB_BUTTONS_HEIGHT[size_ind] - 2)
 
         # Force no decorations for player buttons, this cannot be made to work.
@@ -536,10 +532,6 @@ class GmicButtons(AbstractGlassButtons):
         size_adj = 1
         prefs = editorpersistance.prefs
 
-        # NOT IMPLEMENTED
-        if guiutils.double_icon_size():
-           size_ind = 1
-           size_adj = 2
         AbstractGlassButtons.__init__(self, MB_BUTTON_WIDTH[size_ind], MB_BUTTON_HEIGHT[size_ind], MB_BUTTON_Y, MB_BUTTONS_WIDTH[size_ind], MB_BUTTONS_HEIGHT[size_ind] - 2)
 
         next_icon = guiutils.get_cairo_image("next_frame_s")
