@@ -28,6 +28,7 @@ import cairo
 import copy
 import math
 
+import animatedvalue
 import appconsts
 import clipeffectseditor
 import dialogutils
@@ -106,7 +107,9 @@ _snapping = 1
 # -------------------------------------------------- init
 def load_icons():
     global HAMBURGER_ICON, ACTIVE_KF_ICON, NON_ACTIVE_KF_ICON, ACTIVE_KF_ICON_SMOOTH, \
-    ACTIVE_KF_ICON_DISCRETE, NON_ACTIVE_KF_ICON_SMOOTH, NON_ACTIVE_KF_ICON_DISCRETE
+    ACTIVE_KF_ICON_DISCRETE, NON_ACTIVE_KF_ICON_SMOOTH, NON_ACTIVE_KF_ICON_DISCRETE, \
+    ACTIVE_KF_ICON_EFFECT, ACTIVE_KF_ICON_SMOOTH_EXTENDED, NON_ACTIVE_KF_ICON_EFFECT, \
+    NON_ACTIVE_KF_ICON_SMOOTH_EXTENDED
 
     # Aug-2019 - SvdB - BB
     HAMBURGER_ICON = guiutils.get_cairo_image("hamburger")
@@ -114,9 +117,13 @@ def load_icons():
     ACTIVE_KF_ICON = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "kf_active.png")
     ACTIVE_KF_ICON_SMOOTH = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "kf_active_smooth.png")
     ACTIVE_KF_ICON_DISCRETE = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "kf_active_discrete.png")
+    ACTIVE_KF_ICON_EFFECT = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "kf_active_effect.png") 
+    ACTIVE_KF_ICON_SMOOTH_EXTENDED = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "kf_active_smooth_extended.png") 
     NON_ACTIVE_KF_ICON = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "kf_not_active.png")    
     NON_ACTIVE_KF_ICON_SMOOTH = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "kf_not_active_smooth.png") 
     NON_ACTIVE_KF_ICON_DISCRETE = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "kf_not_active_discrete.png")
+    NON_ACTIVE_KF_ICON_EFFECT = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "kf_not_active_effect.png")
+    NON_ACTIVE_KF_ICON_SMOOTH_EXTENDED = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "kf_not_active_smooth_extended.png")  
 
 def init_tool_for_clip(clip, track, edit_type=VOLUME_KF_EDIT, param_data=None):
     # These can produce data for same objects and we are not (currently) updating
@@ -658,13 +665,13 @@ class TLineKeyFrameEditor:
                     cr.move_to(kf_pos_x_prev, kf_pos_y_prev)
                     cr.line_to(kf_pos_x, kf_pos_y_prev)
                     cr.stroke()
-                elif kf_type_prev == appconsts.KEYFRAME_SMOOTH:
-                    self._draw_smooth_value_curve(cr, i - 1, self.keyframes)
-                else: # LINEAR
+                elif kf_type_prev == appconsts.KEYFRAME_LINEAR:
                     cr.move_to(kf_pos_x_prev, kf_pos_y_prev)
                     cr.line_to(kf_pos_x, kf_pos_y)
                     cr.stroke()
-
+                else: #kf_type_prev == appconsts.KEYFRAME_SMOOTH:
+                    self._draw_smooth_value_curve(cr, i - 1, self.keyframes, kf_type_prev)
+                    
         # If last kf before clip end, continue value curve to end.
         kf, frame, kf_index, kf_type, kf_pos_x, kf_pos_y = kf_positions[-1]
         if kf_pos_x < ex + ew:
@@ -683,20 +690,30 @@ class TLineKeyFrameEditor:
             if frame > self.clip_in + self.clip_length:
                 continue  
                 
-            if kf_index == self.active_kf_index:
+            if kf_index == self.active_kf_index:            
                 if kf_type == appconsts.KEYFRAME_LINEAR:
                     icon = ACTIVE_KF_ICON
                 elif kf_type == appconsts.KEYFRAME_SMOOTH:
                     icon = ACTIVE_KF_ICON_SMOOTH
-                else:
+                elif kf_type == appconsts.KEYFRAME_DISCRETE:
                     icon = ACTIVE_KF_ICON_DISCRETE
+                else:
+                    if kf_type in animatedvalue.EFFECT_KEYFRAME_TYPES:
+                        icon = ACTIVE_KF_ICON_EFFECT
+                    else:
+                        icon = ACTIVE_KF_ICON_SMOOTH_EXTENDED 
             else:
                 if kf_type == appconsts.KEYFRAME_LINEAR:
                     icon = NON_ACTIVE_KF_ICON
                 elif kf_type == appconsts.KEYFRAME_SMOOTH:
                     icon = NON_ACTIVE_KF_ICON_SMOOTH
-                else:
+                elif kf_type == appconsts.KEYFRAME_DISCRETE:
                     icon = NON_ACTIVE_KF_ICON_DISCRETE
+                else:
+                    if kf_type in animatedvalue.EFFECT_KEYFRAME_TYPES:
+                        icon = NON_ACTIVE_KF_ICON_EFFECT
+                    else:
+                        icon = NON_ACTIVE_KF_ICON_SMOOTH_EXTENDED 
                     
             cr.set_source_surface(icon, kf_pos_x - 6, kf_pos_y - 6) # -6 to get kf bitmap center on calculated pixel
             cr.paint()
@@ -994,7 +1011,8 @@ class TLineKeyFrameEditor:
         cr.set_source_rgb(0.8, 0.8, 0.8)
         cr.show_text(text) 
 
-    def _draw_smooth_value_curve(self, cr, i, keyframes):
+    def _draw_smooth_value_curve(self, cr, i, keyframes, interpolated_kf_type):
+
         # Get indexes of the four keyframes that affect the drawn curve. 
         prev = i
         if i == 0:
@@ -1040,6 +1058,7 @@ class TLineKeyFrameEditor:
         # Draw curve using 5 pixel line segments from
         # prev keyframe x position to next keyframe
         # x position.
+        anim_value = animatedvalue.AnimatedValue(keyframes)
         while(more_segments == True):
             end_x = start_x + SEG_LEN_IN_PIX
             if end_x >= kf_pos_next:
@@ -1047,7 +1066,7 @@ class TLineKeyFrameEditor:
                 end_x = kf_pos_next
             
             fract = (end_x - kf_pos_prev) / curve_length
-            end_y_val = self._get_smooth_fract_value(prev_prev, prev, next, next_next, fract, keyframes)
+            end_y_val = anim_value.get_smooth_fract_value(prev_prev, prev, next, next_next, fract, interpolated_kf_type)
             end_y = self._get_panel_y_for_value(end_y_val)
             cr.line_to(end_x, end_y)
 
@@ -1055,6 +1074,7 @@ class TLineKeyFrameEditor:
  
         cr.stroke()
 
+    """
     def _get_smooth_fract_value(self, prev_prev, prev, next, next_next, fract, keyframes):
         frame, val0, kf_type = keyframes[prev_prev]
         frame, val1, kf_type = keyframes[prev]
@@ -1064,6 +1084,7 @@ class TLineKeyFrameEditor:
         smooth_val = self._catmull_rom_interpolate(val0, val1, val2, val3, fract)
         return smooth_val
 
+    
     # These all need to be doubles.
     def _catmull_rom_interpolate(self, y0, y1, y2, y3, t):
         t2 = t * t
@@ -1072,7 +1093,8 @@ class TLineKeyFrameEditor:
         a2 = -0.5 * y0 + 0.5 * y2
         a3 = y1
         return a0 * t * t2 + a1 * t2 + a2 * t + a3
-        
+    """
+    
     def create_round_rect_path(self, cr, x, y, width, height, radius=4.0):
         degrees = math.pi / 180.0
 
@@ -1629,24 +1651,34 @@ class TLineKeyFrameEditor:
     # ------------------------------------------------------------ menus
     def _show_kf_menu(self, event):
         guipopoverclip.kftype_select_popover_menu_show(gui.tline_canvas.widget, self.get_active_kf_type(), event.x, event.y, self._kf_popover_callback)
-
-    def _kf_popover_callback2(self, action, variant):
-        print(action, variant)
         
     def _kf_popover_callback(self, action, variant):
         data = variant.get_string()
-        
-        if data == "linear":
-            self.set_active_kf_type(appconsts.KEYFRAME_LINEAR)
-        elif data == "smooth":
-            self.set_active_kf_type(appconsts.KEYFRAME_SMOOTH)
-        elif data == "discrete":
-            self.set_active_kf_type(appconsts.KEYFRAME_DISCRETE)
 
-        action.set_state(variant)
         guipopoverclip._kf_select_popover.hide()
-        updater.repaint_tline()
 
+        # NOTE: We are not setting 'action.set_state(new_value_variant)'
+        # because we are not using it as state, instead menu in always recreated
+        # on show to active keyframe type.
+
+        try:
+            kf_type = int(data)
+            self.set_active_kf_type(kf_type)
+            self.update_property_value()
+            updater.repaint_tline()
+        except:
+            current_kf_type = self.get_active_kf_type()
+            if data == "effectkfs":
+                animatedvalue.set_effect_keyframe_type(current_kf_type, self.extended_kf_type_set)
+            else:
+                animatedvalue.set_smooth_extended_keyframe_type(current_kf_type, self.extended_kf_type_set)
+            return
+
+    def extended_kf_type_set(self, selected_kf_type):
+        self.set_active_kf_type(selected_kf_type)
+        self.update_property_value()
+        updater.repaint_tline()
+        
     def _show_hamburger_popover(self, widget, event):
         guipopoverclip.kftool_popover_menu_show(widget, self, event.x, event.y, self._popover_callback, self._snapping_menu_item_item_activated)
 
