@@ -39,11 +39,11 @@ from editorstate import current_sequence
 import editorstate
 import gui
 import guicomponents
-import guipopover
 import projectdata
 import patternproducer
 import profilesmanager
 import shortcuts
+import shortcutsdialog
 import respaths
 import workflow
 
@@ -124,12 +124,6 @@ def recreate_media_file_icons():
     recreate_thread = RecreateIconsThread(recreate_progress_window)
     recreate_thread.start()
 
-def show_project_info():
-     dialogs.project_info_dialog(gui.editor_window.window, _show_project_info_callback)
-
-def _show_project_info_callback(dialog, response_id):
-    dialog.destroy()
-
 def about():
     dialogs.about_dialog(gui.editor_window)
 
@@ -246,8 +240,8 @@ def _create_new_kb_shortcuts_group(dialog, response_id, entry):
         root = shortcuts.get_root()
         shortcuts.shortcut_files_display_names.append(root.get('name'))
         shortcuts.set_keyboard_shortcuts()
-        guicomponents.update_shortcuts_combo(dialogs.shortcuts_combo)
-        dialogs.display_keyboard_shortcuts(editorpersistance.prefs.shortcuts, workflow.get_tline_tool_working_set(), dialogs.scroll_hold_panel)
+        shortcutsdialog.update_shortcuts_combo(shortcutsdialog.shortcuts_combo)
+        shortcutsdialog.display_keyboard_shortcuts(editorpersistance.prefs.shortcuts, workflow.get_tline_tool_working_set(), shortcutsdialog.scroll_hold_panel)
         
     dialog.destroy()
 
@@ -255,8 +249,8 @@ def _delete_new_kb_shortcuts_group(dialog, response_id):
     if response_id == Gtk.ResponseType.ACCEPT:
         shortcuts.delete_active_custom_shortcuts_xml()
         shortcuts.set_keyboard_shortcuts()
-        guicomponents.update_shortcuts_combo(dialogs.shortcuts_combo)
-        dialogs.display_keyboard_shortcuts(editorpersistance.prefs.shortcuts, workflow.get_tline_tool_working_set(), dialogs.scroll_hold_panel)
+        shortcutsdialog.update_shortcuts_combo(shortcutsdialog.shortcuts_combo)
+        shortcutsdialog.display_keyboard_shortcuts(editorpersistance.prefs.shortcuts, workflow.get_tline_tool_working_set(), shortcutsdialog.scroll_hold_panel)
         
     dialog.destroy()
 
