@@ -76,29 +76,18 @@ gui_object_names = None
 
 
 # Version 2.10 changed middlebar layout data and we need to create it for all first launches of that app version.
+# KILL in future should not be needed
 def _init_buttons_data():
     if editorpersistance.prefs.midbar_layout_buttons == None: # No data, first launch.
         print("Creating midbar data for 2.10...")
 
         editorpersistance.prefs.cbutton = [True, True, True, True, True, True]
+        editorpersistance.prefs.midbar_layout_buttons = copy.deepcopy(DEFAULT_BUTTONS_TIMECODE_LEFT)
 
-        # appconsts.MIDBAR_TC_FREE is deprecated.appconsts.MIDBAR_COMPONENTS_CENTERED is  mostly same.
-        if editorpersistance.prefs.midbar_layout == appconsts.MIDBAR_TC_FREE:
-            editorpersistance.prefs.midbar_layout == appconsts.MIDBAR_COMPONENTS_CENTERED
-
-        if editorpersistance.prefs.midbar_layout == appconsts.MIDBAR_TC_LEFT:
-            editorpersistance.prefs.midbar_layout_buttons = copy.deepcopy(DEFAULT_BUTTONS_TIMECODE_LEFT)
-        elif editorpersistance.prefs.midbar_layout == appconsts.MIDBAR_TC_CENTER: 
-            editorpersistance.prefs.midbar_layout_buttons = copy.deepcopy(DEFAULT_BUTTONS_TIMECODE_CENTER)
-        elif editorpersistance.prefs.midbar_layout == appconsts.MIDBAR_COMPONENTS_CENTERED:
-            editorpersistance.prefs.midbar_layout_buttons = copy.deepcopy(DEFAULT_BUTTONS_COMPONENTS_CENTERED)
-        
-        editorpersistance.prefs.midbar_layout = appconsts.MIDBAR_TC_LEFT                
         editorpersistance.save()
 
 def _load_layout_data():
-    global current_layout, current_buttons_list, current_active_flags
-    current_layout = editorpersistance.prefs.midbar_layout
+    global current_buttons_list, current_active_flags
     current_buttons_list = editorpersistance.prefs.midbar_layout_buttons
     current_active_flags = editorpersistance.prefs.cbutton
 
@@ -111,12 +100,7 @@ def _save_layout_data():
     original_active_flags = current_active_flags
 
 def redo_layout(w):        
-    if editorpersistance.prefs.midbar_layout == appconsts.MIDBAR_TC_LEFT:
-        _do_TC_LEFT_layout(w)
-    elif editorpersistance.prefs.midbar_layout == appconsts.MIDBAR_TC_CENTER: 
-        _do_TC_MIDDLE_layout(w)
-    elif editorpersistance.prefs.midbar_layout == appconsts.MIDBAR_COMPONENTS_CENTERED:
-        _do_COMPONENTS_CENTERED_layout(w)
+    _do_TC_LEFT_layout(w)
     
 def _show_buttons_TC_LEFT_layout(widget):
     global w
@@ -133,39 +117,6 @@ def _do_TC_LEFT_layout(w):
     _create_buttons(w)
     fill_with_TC_LEFT_pattern(w.edit_buttons_row, w)
     w.window.show_all()
-    
-def _show_buttons_TC_MIDDLE_layout(widget):
-    global w
-    w = gui.editor_window
-    if w == None:
-        return
-    if widget.get_active() == False:
-        return
-
-    _do_TC_MIDDLE_layout(w)
-    
-def _do_TC_MIDDLE_layout(w):
-    _clear_container(w.edit_buttons_row)
-    _create_buttons(w)
-    fill_with_TC_MIDDLE_pattern(w.edit_buttons_row, w)
-    w.window.show_all()
-
-def _show_buttons_COMPONENTS_CENTERED_layout(widget):
-    global w
-    w = gui.editor_window
-    if w == None:
-        return
-    if widget.get_active() == False:
-        return
-
-    _do_COMPONENTS_CENTERED_layout(w)
-    
-def _do_COMPONENTS_CENTERED_layout(w):
-    
-    _clear_container(w.edit_buttons_row)
-    _create_buttons(w)
-    fill_with_COMPONENTS_CENTERED_pattern(w.edit_buttons_row, w)
-    w.window.show_all()
 
 def create_edit_buttons_row_buttons(editor_window, modes_pixbufs):
     _init_buttons_data()
@@ -184,14 +135,9 @@ def create_edit_buttons_row_buttons(editor_window, modes_pixbufs):
     _create_buttons(editor_window)
 
 def _create_buttons(editor_window):
-    
-    # Aug-2019 - SvdB - BB
-    prefs = editorpersistance.prefs
-    size_adj = 1
-    if guiutils.double_icon_size():
-       size_adj = 2
 
     editor_window.big_TC = Gtk.Stack()
+    editor_window.big_TC.set_margin_top(5)
     tc_disp = guicomponents.BigTCDisplay()
     tc_entry = guicomponents.BigTCEntry()
     tc_disp.widget.show()
@@ -201,10 +147,6 @@ def _create_buttons(editor_window):
     editor_window.big_TC.set_visible_child_name("BigTCDisplay")
     gui.big_tc = editor_window.big_TC 
 
-    #surface = guiutils.get_cairo_image("workflow")
-    #editor_window.worflow_launch = guicomponents.PressLaunch(workflow.workflow_menu_launched, surface, w=22*size_adj, h=22*size_adj)
-    #editor_window.worflow_launch.connect_launched_menu(workflow._workflow_menu)
-
     if editorpersistance.prefs.tools_selection == appconsts.TOOL_SELECTOR_IS_MENU:
         editor_window.tool_selector = create_tool_selector(editor_window)
         editor_window.tline_cursor_manager.set_tool_selector_to_mode(editor_window.tool_selector)
@@ -217,17 +159,17 @@ def _create_buttons(editor_window):
         no_decorations = False
 
     # Zoom buttons
-    editor_window.zoom_buttons = glassbuttons.GlassButtonsGroup(38*size_adj, 23*size_adj, 2*size_adj, 8*size_adj, 5*size_adj)
+    editor_window.zoom_buttons = glassbuttons.GlassButtonsGroup(38, 23, 2, 8, 5)
     editor_window.zoom_buttons.add_button(guiutils.get_cairo_image("zoom_in"), updater.zoom_in)
-    editor_window.zoom_buttons.add_button(guiutils.get_cairo_image("zoom_out"), updater.zoom_out, 8*size_adj)
-    editor_window.zoom_buttons.add_button(guiutils.get_cairo_image("zoom_length"), updater.zoom_project_length, 6*size_adj - 1)
+    editor_window.zoom_buttons.add_button(guiutils.get_cairo_image("zoom_out"), updater.zoom_out, 8)
+    editor_window.zoom_buttons.add_button(guiutils.get_cairo_image("zoom_length"), updater.zoom_project_length, 6 - 1)
     tooltips = [_("Zoom In - Mouse Middle Scroll"), _("Zoom Out - Mouse Middle Scroll"), _("Zoom Length - Mouse Middle Click")]
     tooltip_runner = glassbuttons.TooltipRunner(editor_window.zoom_buttons, tooltips)
     editor_window.zoom_buttons.no_decorations = no_decorations
     editor_window.zoom_buttons.show_prelight_icons()
     
     # Cut and dissolve
-    editor_window.edit_buttons = glassbuttons.GlassButtonsGroup(32*size_adj, 23*size_adj, 2*size_adj, 5*size_adj, 5*size_adj)
+    editor_window.edit_buttons = glassbuttons.GlassButtonsGroup(32, 23, 2, 5, 5)
     editor_window.edit_buttons.add_button(guiutils.get_cairo_image("dissolve"), singletracktransition.add_transition_pressed)
     editor_window.edit_buttons.add_button(guiutils.get_cairo_image("cut"), tlineaction.cut_pressed)
     tooltips = [_("Add Rendered Transition - 2 clips selected"), _("Cut Active Tracks - X\nCut All Tracks - Shift + X")]
@@ -236,28 +178,28 @@ def _create_buttons(editor_window):
     editor_window.edit_buttons.show_prelight_icons()
     
     # Delete buttons
-    editor_window.edit_buttons_3 = glassbuttons.GlassButtonsGroup(46*size_adj, 23*size_adj, 2*size_adj, 3*size_adj, 5*size_adj)
-    editor_window.edit_buttons_3.add_button(guiutils.get_cairo_image("splice_out"), tlineaction.splice_out_button_pressed, 10*size_adj)
-    editor_window.edit_buttons_3.add_button(guiutils.get_cairo_image("lift"), tlineaction.lift_button_pressed, 9*size_adj)
-    editor_window.edit_buttons_3.add_button(guiutils.get_cairo_image("ripple_delete"), tlineaction.ripple_delete_button_pressed, 4*size_adj)
-    editor_window.edit_buttons_3.add_button(guiutils.get_cairo_image("delete_range"), tlineaction.delete_range_button_pressed, 4*size_adj)
+    editor_window.edit_buttons_3 = glassbuttons.GlassButtonsGroup(46, 23, 2, 3, 5)
+    editor_window.edit_buttons_3.add_button(guiutils.get_cairo_image("splice_out"), tlineaction.splice_out_button_pressed, 10)
+    editor_window.edit_buttons_3.add_button(guiutils.get_cairo_image("lift"), tlineaction.lift_button_pressed, 9)
+    editor_window.edit_buttons_3.add_button(guiutils.get_cairo_image("ripple_delete"), tlineaction.ripple_delete_button_pressed, 4)
+    editor_window.edit_buttons_3.add_button(guiutils.get_cairo_image("delete_range"), tlineaction.delete_range_button_pressed, 4)
     tooltips = [_("Splice Out - Delete"), _("Lift - Control + Delete"), _("Ripple Delete"), _("Range Delete")]
     tooltip_runner = glassbuttons.TooltipRunner(editor_window.edit_buttons_3, tooltips)
     editor_window.edit_buttons_3.no_decorations = no_decorations
     editor_window.edit_buttons_3.show_prelight_icons()
 
     # Resync and split audio
-    editor_window.edit_buttons_2 = glassbuttons.GlassButtonsGroup(44*size_adj, 23*size_adj, 2*size_adj, 3*size_adj, 5*size_adj)
+    editor_window.edit_buttons_2 = glassbuttons.GlassButtonsGroup(44, 23, 2, 3, 5)
     editor_window.edit_buttons_2.add_button(guiutils.get_cairo_image("split_audio"), tlineaction.split_audio_synched_button_pressed)
     editor_window.edit_buttons_2.add_button(guiutils.get_cairo_image("set_track_sync"), tlineaction.set_track_sync_button_pressed)
     editor_window.edit_buttons_2.add_button(guiutils.get_cairo_image("resync_track"), tlineaction.resync_track_button_pressed)
     editor_window.edit_buttons_2.add_button(guiutils.get_cairo_image("resync"), tlineaction.resync_button_pressed)
-    tooltips = [_("Split Audio Synched"), _("Set Sync for All Clips on Track Containing Selected Clip/s"), _("Resync Track Containing Selected Clip/s"), _("Resync Selected Clips")]
+    tooltips = [_("Split Audio Synched"), _("If <b>single</b> or <b>multi</b> selection set Sync for all Clips on Track Containing Selected Clip/s.\n\nIf <b>box selection</b> set Sync for all selected Clips to first Clip on center most Track."), _("Resync Track Containing Selected Clip/s"), _("Resync Selected Clips")]
     tooltip_runner = glassbuttons.TooltipRunner(editor_window.edit_buttons_2, tooltips)
     editor_window.edit_buttons_2.no_decorations = no_decorations
     editor_window.edit_buttons_2.show_prelight_icons()
 
-    editor_window.monitor_insert_buttons = glassbuttons.GlassButtonsGroup(44*size_adj, 23*size_adj, 2*size_adj, 3*size_adj, 5*size_adj)
+    editor_window.monitor_insert_buttons = glassbuttons.GlassButtonsGroup(44, 23, 2, 3, 5)
     editor_window.monitor_insert_buttons.add_button(guiutils.get_cairo_image("overwrite_range"), tlineaction.range_overwrite_pressed)
     editor_window.monitor_insert_buttons.add_button(guiutils.get_cairo_image("overwrite_clip"), tlineaction.three_point_overwrite_pressed)
     editor_window.monitor_insert_buttons.add_button(guiutils.get_cairo_image("insert_clip"), tlineaction.insert_button_pressed)
@@ -267,7 +209,7 @@ def _create_buttons(editor_window):
     editor_window.monitor_insert_buttons.no_decorations = no_decorations
     editor_window.monitor_insert_buttons.show_prelight_icons()
     
-    editor_window.undo_redo = glassbuttons.GlassButtonsGroup(28*size_adj, 23*size_adj, 2*size_adj, 2*size_adj, 7*size_adj)
+    editor_window.undo_redo = glassbuttons.GlassButtonsGroup(28, 23, 2, 2, 7)
     editor_window.undo_redo.add_button(guiutils.get_cairo_image("undo"), undo.do_undo_and_repaint)
     editor_window.undo_redo.add_button(guiutils.get_cairo_image("redo"), undo.do_redo_and_repaint)
     tooltips = [_("Undo - Ctrl + Z"), _("Redo - Ctrl + Y")]
@@ -275,7 +217,7 @@ def _create_buttons(editor_window):
     editor_window.undo_redo.no_decorations = no_decorations
     editor_window.undo_redo.show_prelight_icons()
     
-    editor_window.tools_buttons = glassbuttons.GlassButtonsGroup(30*size_adj, 23*size_adj, 2*size_adj, 14*size_adj, 7*size_adj)
+    editor_window.tools_buttons = glassbuttons.GlassButtonsGroup(30, 23, 2, 14, 7)
     editor_window.tools_buttons.add_button(guiutils.get_cairo_image("open_mixer"), audiomonitoring.show_audio_monitor)
     editor_window.tools_buttons.add_button(guiutils.get_cairo_image("open_titler"), titler.show_titler)
     editor_window.tools_buttons.add_button(guiutils.get_cairo_image("open_gmic"), gmic.launch_gmic)
@@ -285,17 +227,13 @@ def _create_buttons(editor_window):
     tooltip_runner = glassbuttons.TooltipRunner(editor_window.tools_buttons, tooltips)
     editor_window.tools_buttons.no_decorations = True
     editor_window.tools_buttons.show_prelight_icons()
-    
+
     if editorstate.audio_monitoring_available == False:
         editor_window.tools_buttons.sensitive[0] = False
         editor_window.tools_buttons.widget.set_tooltip_text(_("Audio Mixer(not available)\nTitler"))
 
 def create_tool_selector(editor_window):
-    size_adj = 1
-    if guiutils.double_icon_size():
-       size_adj = 2
-      
-    tool_selector = guicomponents.ToolSelector(editor_window.tline_cursor_manager.mode_selector_pressed, m_pixbufs, 40*size_adj, 22*size_adj)
+    tool_selector = guicomponents.ToolSelector(editor_window.tline_cursor_manager.mode_selector_pressed, m_pixbufs, 40, 22)
     return tool_selector
 
 def re_create_tool_selector(editor_window):
@@ -306,22 +244,18 @@ def fill_with_TC_LEFT_pattern(buttons_row, window):
     global w
     w = window
 
-    #buttons_row.pack_start(w.worflow_launch.widget, False, True, 0)
     buttons_row.pack_start(guiutils.get_pad_label(7, MIDDLE_ROW_HEIGHT), False, True, 0) 
-    buttons_row.pack_start(w.big_TC, False, True, 0)
     buttons_row.pack_start(guiutils.get_pad_label(7, MIDDLE_ROW_HEIGHT), False, True, 0) #### NOTE!!!!!! THIS DETERMINES THE HEIGHT OF MIDDLE ROW
     if editorpersistance.prefs.tools_selection == appconsts.TOOL_SELECTOR_IS_MENU:
         buttons_row.pack_start(w.tool_selector.widget, False, True, 0)
-        if editorstate.SCREEN_WIDTH > 1600:
-            buttons_row.pack_start(guiutils.get_pad_label(80, 10), False, True, 0)
-        else:
-            buttons_row.pack_start(Gtk.Label(), True, True, 0) # For some layout we can't afford additional 60px if w < 1600
             
     if editorstate.screen_size_small_width() == False:
-        pad_w = 30
+        pad_w = 24
     else:
         pad_w = 5
-        
+
+    buttons_row.pack_start(Gtk.Label(), True, True, 0)
+    
     buttons_row.pack_start(get_buttons_group(0), False, True, 0)
     buttons_row.pack_start(guiutils.get_pad_label(pad_w, 10), False, True, 0)
         
@@ -340,80 +274,11 @@ def fill_with_TC_LEFT_pattern(buttons_row, window):
     buttons_row.pack_start(get_buttons_group(5), False, True, 0)
     buttons_row.pack_start(Gtk.Label(), True, True, 0)
 
-def fill_with_TC_MIDDLE_pattern(buttons_row, window):
-    if editorstate.screen_size_small_width() == False:
-        buttons_row.set_homogeneous(True)
-    global w
-    w = window
-    left_panel = Gtk.HBox(False, 0)    
-    left_panel.pack_start(get_buttons_group(0), False, True, 0)
-    left_panel.pack_start(guiutils.get_pad_label(10, MIDDLE_ROW_HEIGHT), False, True, 0) #### NOTE!!!!!! THIS DETERMINES THE HEIGHT OF MIDDLE ROW
-    left_panel.pack_start(get_buttons_group(1), False, True, 0)
-
-    left_panel.pack_start(guiutils.get_pad_label(10, 10), False, True, 0)
-    left_panel.pack_start(get_buttons_group(2), False, True, 0)
-    left_panel.pack_start(Gtk.Label(), True, True, 0)
-
-    middle_panel = Gtk.HBox(False, 0)
-    #middle_panel.pack_start(w.worflow_launch.widget, False, True, 0)
-    middle_panel.pack_start(guiutils.get_pad_label(7, MIDDLE_ROW_HEIGHT), False, True, 0) 
-    middle_panel.pack_start(w.big_TC, False, True, 0)
-    middle_panel.pack_start(guiutils.get_pad_label(10, 10), False, True, 0)
-    if editorpersistance.prefs.tools_selection == appconsts.TOOL_SELECTOR_IS_MENU:
-        middle_panel.pack_start(w.tool_selector.widget, False, True, 0)
-    
-    right_panel = Gtk.HBox(False, 0) 
-    right_panel.pack_start(Gtk.Label(), True, True, 0)
-    right_panel.pack_start(get_buttons_group(3), False, True, 0)
-    right_panel.pack_start(guiutils.get_pad_label(10, 10), False, True, 0)
-
-    right_panel.pack_start(get_buttons_group(4),False, True, 0)
-    right_panel.pack_start(guiutils.get_pad_label(10, 10), False, True, 0)
-    right_panel.pack_start(get_buttons_group(5), False, True, 0)
-
-    buttons_row.pack_start(left_panel, True, True, 0)
-    buttons_row.pack_start(middle_panel, False, False, 0)
-    buttons_row.pack_start(right_panel, True, True, 0)
-
-def fill_with_COMPONENTS_CENTERED_pattern(buttons_row, window):
-    buttons_row.set_homogeneous(False)
-    global w
-    w = window
-    
-    if editorstate.screen_size_small_width() == False:
-        pad_w = 20
-    else:
-        pad_w = 5
-            
-    buttons_row.pack_start(Gtk.Label(), True, True, 0)
-    #buttons_row.pack_start(w.worflow_launch.widget, False, True, 0)
-    buttons_row.pack_start(guiutils.get_pad_label(7, MIDDLE_ROW_HEIGHT), False, True, 0) 
-    buttons_row.pack_start(w.big_TC, False, True, 0)
-    buttons_row.pack_start(guiutils.get_pad_label(7, MIDDLE_ROW_HEIGHT), False, True, 0) #### NOTE!!!!!! THIS DETERMINES THE HEIGHT OF MIDDLE ROW
-    if editorpersistance.prefs.tools_selection == appconsts.TOOL_SELECTOR_IS_MENU:
-        buttons_row.pack_start(w.tool_selector.widget, False, True, 0)
-        if editorstate.SCREEN_WIDTH > 1600:
-            buttons_row.pack_start(guiutils.get_pad_label(80, 10), False, True, 0)
-        else:
-            buttons_row.pack_start(guiutils.get_pad_label(20, 10), False, True, 0)
-
-    buttons_row.pack_start(get_buttons_group(0), False, True, 0)
-    buttons_row.pack_start(guiutils.get_pad_label(pad_w, 10), False, True, 0)
-        
-    buttons_row.pack_start(get_buttons_group(1),False, True, 0)
-    buttons_row.pack_start(guiutils.get_pad_label(pad_w, 10), False, True, 0)
-    
-    buttons_row.pack_start(get_buttons_group(2),False, True, 0)
-    buttons_row.pack_start(guiutils.get_pad_label(pad_w, 10), False, True, 0)
-
-    buttons_row.pack_start(get_buttons_group(3),False, True, 0)
-    buttons_row.pack_start(guiutils.get_pad_label(pad_w, 10), False, True, 0)
-
-    buttons_row.pack_start(get_buttons_group(4),False, True, 0)
-    buttons_row.pack_start(guiutils.get_pad_label(pad_w, 10), False, True, 0)
-
-    buttons_row.pack_start(get_buttons_group(5), False, True, 0)
-    buttons_row.pack_start(Gtk.Label(), True, True, 0)
+    buttons_row.pack_start(window.tools_buttons.widget, False, False, 0)
+    buttons_row.pack_start(guiutils.pad_label(12,2), False, False, 0)
+    buttons_row.pack_start(window.fullscreen_press.widget, False, False, 0)
+    buttons_row.pack_start(guiutils.pad_label(6,2), False, False, 0)
+    buttons_row.pack_start(window.layout_press.widget, False, False, 0)
 
 def _get_zoom_buttons_panel():    
     return w.zoom_buttons.widget
@@ -433,8 +298,10 @@ def _get_edit_buttons_3_panel():
 def _get_monitor_insert_buttons():
     return w.monitor_insert_buttons.widget
 
+"""
 def _get_tools_buttons():
     return w.tools_buttons.widget
+"""
 
 def _b(button, icon, remove_relief=False):
     button.set_image(icon)
@@ -486,7 +353,6 @@ def show_middlebar_conf_dialog():
 
 def _conf_dialog_callback(dialog, response_id, data):
     if response_id == Gtk.ResponseType.ACCEPT:
-        editorpersistance.prefs.midbar_layout = current_layout
         editorpersistance.prefs.midbar_layout_buttons = current_buttons_list
         editorpersistance.prefs.cbutton = current_active_flags
         editorpersistance.save()
@@ -495,7 +361,6 @@ def _conf_dialog_callback(dialog, response_id, data):
         
     else:
         # Cancel conf edits
-        editorpersistance.prefs.midbar_layout = original_layout
         editorpersistance.prefs.midbar_layout_buttons = original_buttons_list
         editorpersistance.prefs.cbutton = original_active_flags
         editorpersistance.save()
@@ -509,18 +374,6 @@ def _get_conf_panel():
     global toolbar_list_box
 
     # Widgets
-    layout_select = Gtk.ComboBoxText()
-    layout_select.set_tooltip_text(_("Select Render quality"))
-    layout_select.append_text(_("Timecode Left"))
-    layout_select.append_text(_("Timecode Center"))
-    layout_select.append_text(_("Components Centered"))
-    layout_select.set_active(prefs.midbar_layout) # indexes correspond with appconsts values.
-    
-    layout_select.connect("changed", lambda w,e: _layout_conf_changed(w), None)
-        
-    layout_row = guiutils.get_left_justified_box([layout_select])
-    layout_frame = guiutils.get_named_frame(_("Layout"), layout_row)
-    
     vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=10)
     choice = Gtk.Label(label=_("Set button group active state and position."))
     
@@ -548,15 +401,11 @@ def _get_conf_panel():
     groups_frame = guiutils.get_named_frame(_("Buttons Groups"), vbox)
     
     pane = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=10)
-    pane.pack_start(layout_frame, False, False, 0)
+    #pane.pack_start(layout_frame, False, False, 0)
     pane.pack_start(groups_frame, False, False, 0)
 
     return pane
 
-def _layout_conf_changed(layout_combo):
-    global current_layout
-    current_layout = layout_combo.get_active()
-
 def toggle_click(button, row_number):
     global current_active_flags
     current_active_flags[row_number] = button.get_active()
