@@ -31,6 +31,7 @@ import json
 
 from gi.repository import Gtk
 
+import animatedvalue
 import appconsts
 from editorstate import current_sequence
 import mlttransitions
@@ -182,6 +183,9 @@ def get_transition_editable_properties(compositor):
     return editable_properties
 
 def get_non_mlt_editable_properties(clip, filter_object, filter_index, track, clip_index):
+    # Creates editable properties that do not write their values to MLT properties.
+    # Sometimes these are just simply not used, sometiemes data is saved in these 
+    # encodes info that gets written into MLT properties.
     editable_properties = []
     for i in range(0, len(filter_object.non_mlt_properties)):
         prop = filter_object.non_mlt_properties[i]
@@ -201,7 +205,7 @@ def get_non_mlt_editable_properties(clip, filter_object, filter_index, track, cl
         editable_properties.append(ep)
     
     return editable_properties
-        
+
 # -------------------------------------------- property wrappers objs
 class AbstractProperty:
     """
@@ -700,12 +704,7 @@ class KeyFrameGeometryOpacityProperty(TransitionEditableProperty):
         for kf in keyframes:
             frame, rect, opac, kf_type = kf
             
-            if kf_type == appconsts.KEYFRAME_LINEAR:
-                eq_str = appconsts.KEYFRAME_LINEAR_EQUALS_STR
-            elif kf_type == appconsts.KEYFRAME_SMOOTH:
-                eq_str = appconsts.KEYFRAME_SMOOTH_EQUALS_STR
-            else:
-                eq_str = appconsts.KEYFRAME_DISCRETE_EQUALS_STR
+            eq_str = animatedvalue.TYPE_TO_EQ_STRING[kf_type]
                         
             val_str += str(int(frame)) + eq_str # frame
             val_str += str(int(rect[0])) + "/" + str(int(rect[1])) + ":" # pos
@@ -730,12 +729,7 @@ class KeyFrameFilterGeometryRectProperty(EditableProperty):
         for kf in keyframes:
             frame, rect, opac, kf_type = kf
             
-            if kf_type == appconsts.KEYFRAME_LINEAR:
-                eq_str = appconsts.KEYFRAME_LINEAR_EQUALS_STR
-            elif kf_type == appconsts.KEYFRAME_SMOOTH:
-                eq_str = appconsts.KEYFRAME_SMOOTH_EQUALS_STR
-            else:
-                eq_str = appconsts.KEYFRAME_DISCRETE_EQUALS_STR
+            eq_str = animatedvalue.TYPE_TO_EQ_STRING[kf_type]
                         
             val_str += str(int(frame)) + eq_str # frame
             val_str += str(int(rect[0])) + " " + str(int(rect[1])) + " " # pos
@@ -855,7 +849,456 @@ class KeyFrameFilterRotatingGeometryProperty:
 
     def update_clip_index(self):
         self.clip_index = self.track.clips.index(self.clip)
+
+# dummytypes as a propertyedit.EditableProperty object.
+class GradientTintExtraEditorProperty:
+
+    def __init__(self, create_params, editable_properties, track, clip_index):
+
+        # Pick up the editable properties that actually have their values being written to on user edits
+        # and affect to filter output.
+        # Relevant filter definition in filters.xml
+        #        <property name="2" args="editor=slider range_in=0,100 displayname=Start!Opacity">0.5</property>
+        #        <property name="4" args="editor=slider range_in=0,100 displayname=End!Opacity">0.5</property>
+        #        <property name="5" args="editor=slider range_in=0,100 displayname=Start!X">0.5</property>
+        #        <property name="6" args="editor=slider range_in=0,100 displayname=Start!Y">0.8</property>
+        self.start_x = [ep for ep in editable_properties if ep.name == "5"][0]
+        self.start_y = [ep for ep in editable_properties if ep.name == "6"][0]
+        self.end_x = [ep for ep in editable_properties if ep.name == "7"][0]
+        self.end_y = [ep for ep in editable_properties if ep.name == "8"][0]
+
+          
+        # Get create data
+        clip, filter_index, p, i, args_str = create_params
+        p_name, p_value, p_type = p
+
+        # We need a lot stuff to ba able to edit this with keyframe editor as
+        # propertyedit.EditableProperty.
+        self.clip = clip
+        self.value = "this is set below"
+        self.is_compositor_filter = False
+        self.track = track
+        self.clip_index = clip_index
+        self.get_input_range_adjustment = lambda : Gtk.Adjustment(value=float(100), lower=float(0), upper=float(100), step_increment=float(1))
+        self.get_display_name = lambda : "Opacity"
+
+        # We also need these to be able to edit this in keyframeeditcanvas.RotatingEditCanvas
+        self.get_pixel_aspect_ratio = lambda : (float(current_sequence().profile.sample_aspect_num()) / current_sequence().profile.sample_aspect_den())
+        self.get_in_value = lambda out_value : out_value # hard coded for opacity 100 -> 100 range
+
+        # This value is parsed to keyframes by keyframecanvas.GradientEditCanvas
+        # using method propertyparse.gradient_tint_geom_keyframes_value_string_to_geom_kf_array(),
+        # and is only used to the initialize the editor. The original design was that editor is given
+        # property value strings, and they then call keyframe_parser() method that is set when editor is 
+        # build for particular type of property string. Here we need to write out keyframes
+        # to multiple different properties, so this "dummy" editable property is created to act as the 
+        # property being edited, and it converts editor output to property values of the properties
+        # in method write_out_keyframes() below.
+        self.value = self.get_value_keyframes_str()
+
+    def get_clip_length(self):
+        return self.clip.clip_out - self.clip.clip_in + 1
         
+    def get_clip_tline_pos(self):
+        return self.track.clip_start(self.clip_index)
+        
+    def get_value_keyframes_str(self):
+        # Create input string for keyframecanvas.RotatingEditCanvas editor.
+        start_x_tokens = self.start_x.value.split(";")
+        start_y_tokens = self.start_y.value.split(";")
+        end_x_tokens = self.end_x.value.split(";")
+        end_y_tokens = self.end_y.value.split(";")
+
+        value = ""
+        for i in range(0, len(start_x_tokens)): # these all have the asme amount of keyframes always
+            start_x_token = start_x_tokens[0]
+            start_y_token = start_y_tokens[0]
+            end_x_token = end_x_tokens[0]
+            end_y_token = end_y_tokens[0]
+
+            frame, start_x, kf_type = propertyparse.get_token_frame_value_type(start_x_token)
+            frame, start_y, kf_type = propertyparse.get_token_frame_value_type(start_y_token)
+            frame, end_x, kf_type = propertyparse.get_token_frame_value_type(end_x_token)
+            frame, end_y, kf_type = propertyparse.get_token_frame_value_type(end_y_token)
+
+            eq_str = propertyparse._get_eq_str(kf_type)
+
+            frame_str = str(frame) + eq_str + str(start_x) + ":" + str(start_y) + ":" + str(end_x) + ":" + str(end_y)
+            value += frame_str + ";"
+
+        # This value is parsed as keyframes in propertyparse.gradient_tint_geom_keyframes_value_string_to_geom_kf_array()
+        value = value.strip(";")
+
+        return value
+
+    def get_input_range_adjustment(self):
+        # Returns DUMMY noop Adjustment that needs to exist because AbstrackKeyframeEditor assumes a slider always exists,
+        # but this not the case for this editor/property pair.
+  
+        return Gtk.Adjustment(value=float(1.0), lower=float(0.0), upper=float(1.0), step_increment=float(0.01)) # Value set later to first kf value
+        
+    def write_out_keyframes(self, keyframes):
+
+        start_x_val = ""
+        start_y_val = ""
+        end_x_val = ""
+        end_y_val = "" 
+        
+        profile_width = float(current_sequence().profile.width())
+        profile_height = float(current_sequence().profile.height())
+    
+        for kf in keyframes:
+
+            frame, values, kf_type = kf
+            start_x, start_y, end_x, end_y = values
+            
+            eq_str = propertyparse._get_eq_str(kf_type)
+
+            # Editor keyframes are in pixel coords, filter wants normalised coods.
+            start_x_tr = start_x / profile_width
+            start_y_tr = start_y / profile_height
+            end_x_tr = end_x / profile_width
+            end_y_tr = end_y / profile_height
+            
+            # Build kf value strings
+            start_x_val += str(frame) + eq_str + str(start_x_tr) + ";"
+            start_y_val += str(frame) + eq_str + str(start_y_tr) + ";"
+            end_x_val += str(frame) + eq_str + str(end_x_tr) + ";"
+            end_y_val += str(frame) + eq_str +  str(end_y_tr) + ";"
+
+        start_x_val.strip(";")
+        start_y_val.strip(";")
+        end_x_val.strip(";")
+        end_y_val.strip(";")
+        
+        self.start_x.write_value(start_x_val)
+        self.start_y.write_value(start_y_val)
+        self.end_x.write_value(end_x_val)
+        self.end_y.write_value(end_y_val)
+        
+    def write_value(self, str_value):
+        pass
+         
+    def write_mlt_property_str_value(self, str_value):
+        pass
+         
+    def write_filter_object_property(self, str_value):
+        pass
+
+    def update_clip_index(self):
+        self.clip_index = self.track.clips.index(self.clip)
+
+
+# dummytypes as a propertyedit.EditableProperty object.
+class CropEditorProperty:
+
+    def __init__(self, create_params, editable_properties, track, clip_index):
+
+        # Pick up the editable properties that actually have their values being written to on user edits
+        # and affect to filter output.
+        # Relevant filter definition in filters.xml
+        # <property name="Left" args="range_in=0.0,100.0 editor=slider step=0.1 scale_digits=1">0</property>
+        # <property name="Right" args="range_in=0.0,100.0 editor=slider step=0.1 scale_digits=1">0</property>
+        #<property name="Top" args="range_in=0.0,100.0 editor=slider step=0.1 scale_digits=1">0</property>
+        # <property name="Bottom" args="range_in=0.0,100.0 editor=slider step=0.1 scale_digits=1">0</property>
+        self.left = [ep for ep in editable_properties if ep.name == "Left"][0]
+        self.right = [ep for ep in editable_properties if ep.name == "Right"][0]
+        self.top = [ep for ep in editable_properties if ep.name == "Top"][0]
+        self.bottom = [ep for ep in editable_properties if ep.name == "Bottom"][0]
+
+        # Get create data
+        clip, filter_index, p, i, args_str = create_params # p is a NonMltEditableProperty created for the extara editor 
+                                                           # that uses this property but we don't use it anything, 
+                                                           # editor values are written to the four editable properties above.
+
+        # We need a lot stuff to ba able to edit this with keyframe editor as
+        # propertyedit.EditableProperty.
+        self.clip = clip
+        self.value = "this is set below"
+        self.is_compositor_filter = False
+        self.track = track
+        self.clip_index = clip_index
+        self.get_input_range_adjustment = lambda : Gtk.Adjustment(value=float(100), lower=float(0), upper=float(100), step_increment=float(1))
+        self.get_display_name = lambda : "Opacity"
+
+        # We also need these to be able to edit this in keyframeeditcanvas.RotatingEditCanvas
+        self.get_pixel_aspect_ratio = lambda : (float(current_sequence().profile.sample_aspect_num()) / current_sequence().profile.sample_aspect_den())
+        self.get_in_value = lambda out_value : out_value 
+
+        # This value is parsed to keyframes by keyframecanvas.CropEditingCAnvas
+        # using method propertyparse.crop_geom_keyframes_value_string_to_geom_kf_array(),
+        # and is only used to the initialize the editor. The original design was that editor is given
+        # property value strings, and they then call keyframe_parser() method that is set when editor is 
+        # build for particular type of property string. Here we need to write out keyframes
+        # to _two_ different properties, so this "dummy" editable property is created to act as the 
+        # property being edited, and it converts editor output to property values of two different 
+        # properties in method write_out_keyframes() below.
+        self.value = self.get_value_keyframes_str()
+
+    def get_clip_length(self):
+        return self.clip.clip_out - self.clip.clip_in + 1
+        
+    def get_clip_tline_pos(self):
+        return self.track.clip_start(self.clip_index)
+        
+    def get_value_keyframes_str(self):
+        # Create input string for keyframecanvas.BoxEditCanvas editor from
+        # values being edited.
+        # Parsed to keyframes used by keyframecanvas.BoxEditCanvas at
+        # propertyparse.crop_geom_keyframes_value_string_to_geom_kf_array()
+        left_tokens = self.left.value.strip(";").split(";")
+        right_tokens = self.right.value.strip(";").split(";")
+        top_tokens = self.top.value.strip(";").split(";")
+        bottom_tokens = self.bottom.value.strip(";").split(";")
+
+        value = ""
+        for i in range(0, len(left_tokens)): # these all have the same amount of keyframes always
+            left_token = left_tokens[i]
+            right_token = right_tokens[i]
+            top_token = top_tokens[i]
+            bottom_token = bottom_tokens[i]
+
+            frame, left, kf_type = propertyparse.get_token_frame_value_type(left_token)
+            frame, right, kf_type = propertyparse.get_token_frame_value_type(right_token)
+            frame, top, kf_type = propertyparse.get_token_frame_value_type(top_token)
+            frame, bottom, kf_type = propertyparse.get_token_frame_value_type(bottom_token)
+
+            eq_str = propertyparse._get_eq_str(kf_type)
+
+            frame_str = str(frame) + eq_str + str(left) + ":" + str(right) + ":" + str(top) + ":" + str(bottom)
+            value += frame_str + ";"
+
+        # This value is parsed as keyframes in propertyparse.crop_geom_keyframes_value_string_to_geom_kf_array()
+        value = value.strip(";")
+
+        return value
+
+    def get_input_range_adjustment(self):
+        # Returns DUMMY noop Adjustment that needs to exist because AbstrackKeyframeEditor assumes a slider always exists,
+        # but this not the case for this editor/property pair.
+  
+        return Gtk.Adjustment(value=float(1.0), lower=float(0.0), upper=float(1.0), step_increment=float(0.01)) # Value set later to first kf value
+        
+    def write_out_keyframes(self, keyframes):
+
+        left_val = ""
+        right_val = ""
+        top_val = ""
+        bottom_val = "" 
+        
+        profile_width = float(current_sequence().profile.width())
+        profile_height = float(current_sequence().profile.height())
+    
+        for kf in keyframes:
+
+            frame, rect, opacity, kf_type = kf
+            x = rect[0]
+            y = rect[1]
+            w = rect[2]
+            h = rect[3] 
+
+            eq_str = propertyparse._get_eq_str(kf_type) 
+
+            # Editor keyframes are in pixel coords, filter wants normalised coods.
+            left_tr = self._clamp_norm(x / profile_width)
+            right_tr = self._clamp_norm((profile_width - (x + w)) / profile_width)
+            top_tr = self._clamp_norm(y / profile_height)
+            bottom_tr = self._clamp_norm((profile_height - (y + h)) / profile_height)
+            
+            # Build kf value strings
+            left_val += str(frame) + eq_str + str(left_tr) + ";"
+            right_val += str(frame) + eq_str + str(right_tr) + ";"
+            top_val += str(frame) + eq_str + str(top_tr) + ";"
+            bottom_val += str(frame) + eq_str +  str(bottom_tr) + ";"
+
+        left_val.strip(";")
+        right_val.strip(";")
+        top_val.strip(";")
+        bottom_val.strip(";")
+        
+        self.left.write_value(left_val)
+        self.right.write_value(right_val)
+        self.top.write_value(top_val)
+        self.bottom.write_value(bottom_val)
+
+    def _clamp_norm(self, val):
+        if val < 0.0:
+            val = 0.0
+        elif val > 1.0:
+            val = 1.0
+        
+        return val
+
+    def write_value(self, str_value):
+        pass
+         
+    def write_mlt_property_str_value(self, str_value):
+        pass
+         
+    def write_filter_object_property(self, str_value):
+        pass
+
+    def update_clip_index(self):
+        self.clip_index = self.track.clips.index(self.clip)
+
+
+class AlphaShapeRotatingGeometryProperty:
+
+    def __init__(self, create_params, editable_properties, track, clip_index):
+
+        # Pick up the editable properties that actually have their values being written to on user edits
+        # and affect to filter output.
+        #<property name="Position X" args="range_in=0,100 editor=keyframe_editor exptype=keyframe_hcs displayname=Pos!X">0=0.5</property>
+        #<property name="Position Y" args="range_in=0,100 editor=keyframe_editor exptype=keyframe_hcs displayname=Pos!Y">0=0.5</property>
+        #<property name="Size X" args="range_in=0,100 editor=keyframe_editor exptype=keyframe_hcs displayname=Size!X">0=0.5</property>
+        #<property name="Size Y" args="range_in=0,100 editor=keyframe_editor exptype=keyframe_hcs displayname=Size!Y">0=0.5</property>
+        #<property name="Tilt" args="range_in=0,100 editor=keyframe_editor exptype=keyframe_hcs displayname=Tilt">0=0.5</property>
+        
+        self.pos_x = [ep for ep in editable_properties if ep.name == "Position X"][0]
+        self.pos_y = [ep for ep in editable_properties if ep.name == "Position Y"][0]
+        self.size_x = [ep for ep in editable_properties if ep.name == "Size X"][0]
+        self.size_y = [ep for ep in editable_properties if ep.name == "Size Y"][0]
+        self.tilt = [ep for ep in editable_properties if ep.name == "Tilt"][0]
+        
+        # Get create data
+        clip, filter_index, p, i, args_str = create_params
+        p_name, p_value, p_type = p
+
+        # We need a lot stuff to ba able to edit this with keyframe editor as
+        # propertyedit.EditableProperty.
+        self.clip = clip
+        self.value = "this is set below"
+        self.is_compositor_filter = False
+        self.track = track
+        self.clip_index = clip_index
+        self.get_input_range_adjustment = lambda : Gtk.Adjustment(value=float(100), lower=float(0), upper=float(100), step_increment=float(1))
+        self.get_display_name = lambda : "Opacity"
+
+        # We also need these to be able to edit this in keyframeeditcanvas.RotatingEditCanvas
+        self.get_pixel_aspect_ratio = lambda : (float(current_sequence().profile.sample_aspect_num()) / current_sequence().profile.sample_aspect_den())
+        self.get_in_value = lambda out_value : out_value # hard coded for opacity 100 -> 100 range
+
+        # This value is parsed to keyframes by keyframecanvas.RotatingEditCanvas
+        # using method propertyparse.filter_rotating_geom_keyframes_value_string_to_geom_kf_array(),
+        # and is only used to the initialize the editor. The original design was that editor is given
+        # property value strings, and they then call keyframe_parser() method that is set when editor is 
+        # build for particular type of property string. Here we need to write out keyframes
+        # to _two_ different properties, so this "dummy" editable property is created to act as the 
+        # property being edited, and it converts editor output to property values of two different 
+        # properties in method write_out_keyframes() below.
+        self.value = self.get_value_keyframes_str()
+
+    def get_clip_length(self):
+        return self.clip.clip_out - self.clip.clip_in + 1
+        
+    def get_clip_tline_pos(self):
+        return self.track.clip_start(self.clip_index)
+        
+    def get_value_keyframes_str(self):
+        # Create input string for keyframecanvas.RotatingEditCanvas editor.
+        pos_x_tokens = self.pos_x.value.strip(";").split(";")
+        pos_y_tokens = self.pos_y.value.strip(";").split(";")
+        size_x_tokens = self.size_x.value.strip(";").split(";")
+        size_y_tokens = self.size_y.value.strip(";").split(";")
+        tilt_tokens = self.tilt.value.strip(";").split(";")
+
+        profile_width = float(current_sequence().profile.width())
+        profile_height = float(current_sequence().profile.height())
+        
+        value = ""
+        for i in range(0, len(pos_x_tokens)):
+            pos_x_token = pos_x_tokens[i]
+            pos_y_token = pos_y_tokens[i]
+            size_x_token = size_x_tokens[i]
+            size_y_token = size_y_tokens[i]
+            tilt_token = tilt_tokens[i]
+            frame, x, kf_type = propertyparse.get_token_frame_value_type(pos_x_token)
+            frame, y, kf_type = propertyparse.get_token_frame_value_type(pos_y_token)
+            frame, w, kf_type = propertyparse.get_token_frame_value_type(size_x_token)
+            frame, h, kf_type = propertyparse.get_token_frame_value_type(size_y_token)
+            frame, tilt, kf_type = propertyparse.get_token_frame_value_type(tilt_token)
+
+            x_scale = (float(w) * 2.0)
+            y_scale = (float(h) * 2.0)
+            x_tr = (float(x) - 0.5 * x_scale) * profile_width 
+            y_tr = (float(y) - 0.5 * y_scale) * profile_height
+            size_x_tr = float(w) * 2.0 * profile_width
+            size_y_tr = float(h) * 2.0 * profile_height
+            rotation = (float(tilt) - 0.5) * 360.0 
+            
+            eq_str = propertyparse._get_eq_str(kf_type)
+
+            frame_str = str(frame) + eq_str + str(x_tr) + ":" + str(y_tr) + ":" + str(size_x_tr) + ":" + str(size_y_tr) + ":" + str(rotation)
+            value += frame_str + ";"
+
+        # This value is parsed as keyframes in propertyparse.filter_rotating_geom_keyframes_value_string_to_geom_kf_array()
+        value = value.strip(";")
+
+        return value
+
+    def get_input_range_adjustment(self):
+        # Returns DUMMY noop Adjustment that needs to exist because AbstrackKeyframeEditor assumes a slider always exists,
+        # but this not the case for this editor/property pair.
+  
+        return Gtk.Adjustment(value=float(1.0), lower=float(0.0), upper=float(1.0), step_increment=float(0.01)) # Value set later to first kf value
+        
+    def write_out_keyframes(self, keyframes):    
+        pos_x_val = ""
+        pos_y_val = ""
+        size_x_val = ""
+        size_y_val = ""
+        tilt_val = ""
+
+        profile_width = float(current_sequence().profile.width())
+        profile_height = float(current_sequence().profile.height())
+    
+        for kf in keyframes:
+            frame, transf, opacity, kf_type = kf
+            x, y, x_scale, y_scale, rotation = transf
+            
+            eq_str = propertyparse._get_eq_str(kf_type)
+
+            # Editor keyframes are in pixel coords, filter wants 0 - 1, where 0.5 is non-transformed value. 
+            pos_x_tr = (x - (profile_width / 2.0)) / profile_width + 0.5
+            pos_y_tr = (y - (profile_height / 2.0)) / profile_height + 0.5
+            size_x_tr = x_scale / 2.0
+            size_y_tr = y_scale / 2.0
+            tilt_tr = rotation / 360.0 + 0.5
+            
+            # Build kf value strings
+            pos_x_val += str(frame) + eq_str + str(pos_x_tr) + ";"
+            pos_y_val += str(frame) + eq_str + str(pos_y_tr) + ";"
+            size_x_val += str(frame) + eq_str + str(size_x_tr) + ";"
+            size_y_val += str(frame) + eq_str +  str(size_y_tr) + ";"
+            tilt_val += str(frame) + eq_str +  str(tilt_tr) + ";"
+
+
+
+        pos_x_val = pos_x_val.strip(";")
+        pos_y_val = pos_y_val.strip(";")
+        size_x_val = size_x_val.strip(";")
+        size_y_val = size_y_val.strip(";")
+        tilt_val = tilt_val.strip(";")
+
+        self.pos_x.write_value(pos_x_val)
+        self.pos_y.write_value(pos_y_val)
+        self.size_x.write_value(size_x_val)
+        self.size_y.write_value(size_y_val)
+        self.tilt.write_value(tilt_val)
+ 
+    def write_value(self, str_value):
+        pass
+         
+    def write_mlt_property_str_value(self, str_value):
+        pass
+         
+    def write_filter_object_property(self, str_value):
+        pass
+
+    def update_clip_index(self):
+        self.clip_index = self.track.clips.index(self.clip)
+        
+
 class FreiGeomHCSTransitionProperty(TransitionEditableProperty):
     def __init__(self, params):
         TransitionEditableProperty.__init__(self, params)
@@ -880,13 +1323,8 @@ class KeyFrameHCSFilterProperty(EditableProperty):
         for kf in keyframes:
             frame, val, kf_type = kf
             
-            if kf_type == appconsts.KEYFRAME_LINEAR:
-                eq_str = appconsts.KEYFRAME_LINEAR_EQUALS_STR
-            elif kf_type == appconsts.KEYFRAME_SMOOTH:
-                eq_str = appconsts.KEYFRAME_SMOOTH_EQUALS_STR
-            else:
-                eq_str = appconsts.KEYFRAME_DISCRETE_EQUALS_STR
-                
+            eq_str = animatedvalue.TYPE_TO_EQ_STRING[kf_type]
+            
             val_str += str(frame) + eq_str + str(self.get_out_value(val)) + ";"
         
         val_str = val_str.strip(";")
@@ -909,7 +1347,7 @@ class RotoJSONProperty(EditableProperty):
 
 class KeyFrameHCSTransitionProperty(TransitionEditableProperty):
     """
-    Coverts array of keyframe tuples to string of type "0=0.2;123=0.143"
+    Converts array of keyframe tuples to string of type "0=0.2;123=0.143"
     """
     def __init__(self, params):
         TransitionEditableProperty.__init__(self, params)
