@@ -87,10 +87,3 @@ def set_paths(root_path):
     FLUXITY_API_DOC = root_path + "/res/mediaplugins/fluxity.html"
     INFO_TIPS_DOC = root_path + "/res/help/en/infotips.html"
     USBHID_DRIVERS_PATH = root_path + "/res/usbhid/"
-    
-def apply_dark_theme():
-    global IMAGE_PATH
-    IMAGE_PATH = ROOT_PATH + "/res/darktheme/"
-
-
-
