@@ -151,12 +151,11 @@ def _get_dynamic_kb_shortcuts_panel(xml_file, tool_set):
     tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "cut_all"), False, False, 0)
     tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "trim_start"), False, False, 0)
     tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "trim_end"), False, False, 0)
+    tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "set_length"), False, False, 0)
     tline_vbox.pack_start(_get_kb_row(_("DELETE"),  _("Splice Out")), False, False, 0)
     tline_vbox.pack_start(_get_kb_row(_("Control + DELETE"),  _("Lift")), False, False, 0)
     tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "clear_filters"), False, False, 0)
-    tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "split_selected"), False, False, 0)
-    tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "resync"), False, False, 0)
-    tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "sync_all"), False, False, 0)
+
     tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "insert"), False, False, 0)
     tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "append"), False, False, 0)
     tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "append_from_bin"), False, False, 0)
@@ -165,6 +164,7 @@ def _get_dynamic_kb_shortcuts_panel(xml_file, tool_set):
     tline_vbox.pack_start(_get_kb_row(_("Control + C"), _("Copy Clips")), False, False, 0)
     tline_vbox.pack_start(_get_kb_row(_("Control + V"), _("Paste Clips")), False, False, 0)
     tline_vbox.pack_start(_get_kb_row(_("Shift + Control + V"), _("Paste Filters/Properties")), False, False, 0)
+    tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "toggle_audio_mute"), False, False, 0)
     tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "nudge_back"), False, False, 0)
     tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "nudge_forward"), False, False, 0)
     tline_vbox.pack_start(_get_dynamic_kb_row(root_node, "nudge_back_10"), False, False, 0)
@@ -187,6 +187,14 @@ def _get_dynamic_kb_shortcuts_panel(xml_file, tool_set):
     trimming_box.pack_start(_get_kb_row(_("ENTER"),  _("Complete Keyboard Trim Edit")), False, False, 0) #  _get_dynamic_kb_row(root_node, "enter_edit"), False, False, 0)
     trimming = guiutils.get_named_frame(_("Trimming"), trimming_box)
 
+    sync_box = Gtk.VBox()
+    sync_box.pack_start(_get_dynamic_kb_row(root_node, "split_selected"), False, False, 0)
+    sync_box.pack_start(_get_dynamic_kb_row(root_node, "resync"), False, False, 0)
+    sync_box.pack_start(_get_dynamic_kb_row(root_node, "set_sync_relation"), False, False, 0)
+    sync_box.pack_start(_get_dynamic_kb_row(root_node, "clear_sync_relation"), False, False, 0)
+    sync_box.pack_start(_get_dynamic_kb_row(root_node, "sync_all"), False, False, 0)
+    sync = guiutils.get_named_frame(_("Sync"), sync_box)
+
     marks_box = Gtk.VBox()
     marks_box.pack_start(_get_dynamic_kb_row(root_node, "mark_in"), False, False, 0)
     marks_box.pack_start(_get_dynamic_kb_row(root_node, "mark_out"), False, False, 0)
@@ -269,6 +277,8 @@ def _get_dynamic_kb_shortcuts_panel(xml_file, tool_set):
     panel.pack_start(guiutils.pad_label(12,12), False, False, 0)
     panel.pack_start(trimming, False, False, 0)
     panel.pack_start(guiutils.pad_label(12,12), False, False, 0)
+    panel.pack_start(sync, False, False, 0)
+    panel.pack_start(guiutils.pad_label(12,12), False, False, 0)
     panel.pack_start(marks, False, False, 0)
     panel.pack_start(guiutils.pad_label(12,12), False, False, 0)
     panel.pack_start(track_head, False, False, 0)
