@@ -22,10 +22,11 @@
 This module handles track actions; mute, change active state, size change.
 """
 
-from gi.repository import GLib
+from gi.repository import GLib, Gtk
 
 import appconsts
 import audiomonitoring
+import dialogutils
 import gui
 import guipopover
 import editorstate
@@ -76,12 +77,33 @@ def unlock_track(track_index):
     track.edit_freedom = appconsts.FREE
     updater.repaint_tline()
 
+def edit_info_label(track_index):
+    track = get_track(track_index)
+    dialog, entry = dialogutils.get_single_line_text_input_dialog(30, 130,
+                                                _("Set Track Info Text"),
+                                                _("Set"),
+                                                _("Track Info Text:"),
+                                                track.info_label)
+    dialog.connect('response', _set_track_info_text_callback, entry, track)
+    dialog.show_all()
+
+def _set_track_info_text_callback(dialog, response_id, entry, track):
+    if response_id == Gtk.ResponseType.ACCEPT:
+        track.info_label = entry.get_text()
+        updater.repaint_tline()
+
+    dialog.destroy()
 
 def set_track_sync(track_index):
     child_track = get_track(track_index)
     syncsplitevent.set_track_clips_sync(child_track)
 
-def reset_treack_sync(track_index):
+def set_track_sync_from_popover(track_index):
+
+    child_track = get_track(track_index)
+    syncsplitevent.set_track_clips_sync(child_track)
+
+def reset_track_sync(track_index):
     child_track = get_track(track_index)
     parent_track = child_track.parent_track
     syncsplitevent.do_set_track_clips_sync(child_track, parent_track)
@@ -351,6 +373,7 @@ def track_double_click(track_id):
         set_track_normal_height(track_id)
     
 def track_center_pressed(data):
+
     if data.event.button == 1:
         # handle possible mute icon presses
         press_x = data.event.x
@@ -359,22 +382,25 @@ def track_center_pressed(data):
         if track == None:
             return
         y_off = press_y - tlinewidgets._get_track_y(track.id)
-        ICON_WIDTH = 14
-        ICON_HEIGHT = 10
+        AUDIO_ICON_WIDTH = 12
+        VIDEO_ICON_WIDTH = 14
+        AUDIO_ICON_X = 7
+        VIDEO_ICON_X = AUDIO_ICON_X + AUDIO_ICON_WIDTH
+        ICON_HEIGHT = 22
 
-        X_CORR_OFF = 4 # icon edge not on image left edge
-        if press_x > tlinewidgets.COLUMN_LEFT_PAD + X_CORR_OFF and press_x < tlinewidgets.COLUMN_LEFT_PAD + ICON_WIDTH + X_CORR_OFF:
-            # Mute icon x area hit
-            ix, iy = tlinewidgets.MUTE_ICON_POS
-            if track.height == appconsts.TRACK_HEIGHT_HIGH:
-                ix, iy = tlinewidgets.MUTE_ICON_POS_HIGH
-            elif track.height == appconsts.TRACK_HEIGHT_NORMAL: 
-                ix, iy = tlinewidgets.MUTE_ICON_POS_NORMAL
+        ix, iy = tlinewidgets.MUTE_ICON_POS
+        if track.height == appconsts.TRACK_HEIGHT_HIGH:
+            ix, iy = tlinewidgets.MUTE_ICON_POS_HIGH
+        elif track.height == appconsts.TRACK_HEIGHT_NORMAL: 
+            ix, iy = tlinewidgets.MUTE_ICON_POS_NORMAL
 
-            if track.id >= current_sequence().first_video_index:
-                # Video tracks
-                # Test mute switches
-                if y_off > iy and y_off < iy + ICON_HEIGHT:
+        new_mute_state = track.mute_state
+        
+        if track.id >= current_sequence().first_video_index:
+            # Video tracks
+            # Test mute switches
+            if y_off > iy and y_off < iy + ICON_HEIGHT:
+                if press_x > VIDEO_ICON_X and press_x < VIDEO_ICON_X + VIDEO_ICON_WIDTH:
                     # Video mute icon hit
                     if track.mute_state == appconsts.TRACK_MUTE_NOTHING:
                         new_mute_state = appconsts.TRACK_MUTE_VIDEO
@@ -384,7 +410,7 @@ def track_center_pressed(data):
                         new_mute_state = appconsts.TRACK_MUTE_ALL
                     elif track.mute_state == appconsts.TRACK_MUTE_ALL:
                         new_mute_state = appconsts.TRACK_MUTE_AUDIO
-                elif y_off > iy + ICON_HEIGHT and y_off < iy + ICON_HEIGHT * 2:
+                elif press_x > AUDIO_ICON_X and press_x < AUDIO_ICON_X + AUDIO_ICON_WIDTH:
                     # Audio mute icon hit
                     if track.mute_state == appconsts.TRACK_MUTE_NOTHING:
                         new_mute_state = appconsts.TRACK_MUTE_AUDIO
@@ -394,24 +420,24 @@ def track_center_pressed(data):
                         new_mute_state = appconsts.TRACK_MUTE_NOTHING
                     elif track.mute_state == appconsts.TRACK_MUTE_ALL:
                         new_mute_state = appconsts.TRACK_MUTE_VIDEO
+        else:
+            # Audio tracks
+            # Test mute switches
+            if y_off > iy and y_off < iy + ICON_HEIGHT \
+                and press_x > AUDIO_ICON_X and press_x < AUDIO_ICON_X + AUDIO_ICON_WIDTH:
+                if track.mute_state == appconsts.TRACK_MUTE_VIDEO:
+                    new_mute_state = appconsts.TRACK_MUTE_ALL
                 else:
-                    return
-            else:
-                # Audio tracks
-                # Test mute switches
-                iy = iy + 6 # Mute icon is lower on audio tracks
-                if y_off > iy and y_off < iy + ICON_HEIGHT:
-                    if track.mute_state == appconsts.TRACK_MUTE_VIDEO:
-                        new_mute_state = appconsts.TRACK_MUTE_ALL
-                    else:
-                        new_mute_state = appconsts.TRACK_MUTE_VIDEO
-                else:
-                    return 
-            # Update track mute state
-            current_sequence().set_track_mute_state(track.id, new_mute_state)
-            
-            audiomonitoring.update_mute_states()
-            gui.tline_column.widget.queue_draw()
+                    new_mute_state = appconsts.TRACK_MUTE_VIDEO
+
+        if new_mute_state == track.mute_state:
+            return # Don't update if nothing hit.
+        
+        # Update track mute state
+        current_sequence().set_track_mute_state(track.id, new_mute_state)
+        
+        audiomonitoring.update_mute_states()
+        gui.tline_column.widget.queue_draw()
     
     if data.event.button == 3:
         global _menu_track_index # popover + gio.actions just wont allow easily packing track to go, so we're going global
@@ -421,10 +447,14 @@ def track_center_pressed(data):
                                             _track_menu_item_activated,
                                             _track_menu_height_activated)
 
+
+
 POPUP_HANDLERS = {"lock":lock_track,
                   "unlock":unlock_track,
                   "mute_track":mute_track,
                   "clearsync":clear_track_sync,
                   "resync":resync_track,
                   "setsync":set_track_sync,
-                  "ressetsync":reset_treack_sync}
+                  "setsyncfrompopover":set_track_sync_from_popover,
+                  "resetsync":reset_track_sync, 
+                  "infolabel":edit_info_label}
