@@ -33,9 +33,6 @@ import gui
 import tlinewidgets
 import updater
 
-
-import traceback
-
 # Default value for pre- and post roll in loop playback
 DEFAULT_LOOP_HALF_LENGTH = 25
 
@@ -83,6 +80,9 @@ def clear_edit_data():
     ripple_data = None
     mouse_disabled = False
 
+def submode_is_keyb_edit_on():
+    return (submode == KEYB_EDIT_ON)
+        
 def _get_trim_edit(track, frame):
     """
     Return a trim edit for a frame on a track.
@@ -250,6 +250,40 @@ def set_no_edit_trim_mode():
 
 
 #----------------------------------------------------- keyboard events
+def move_delta(delta):
+    # N.B. not a keyboard event per se, but allows a jog wheel
+    # to move multiple frames during one trim action
+
+    global submode
+
+    if delta == 0:
+        return
+
+    if submode == MOUSE_EDIT_ON:
+        return
+
+    submode = KEYB_EDIT_ON
+
+    if delta < 0:
+        # we received a negative delta value implying direction and amount
+        # but we have to turn it into a positive number to call the functions
+        # that assume movement left with a positive amount
+        delta = abs(delta)
+
+        if EDIT_MODE() == editorstate.ONE_ROLL_TRIM:
+            _one_roll_trim_left(delta)
+        elif EDIT_MODE() == editorstate.TWO_ROLL_TRIM:
+            _tworoll_trim_left(delta)
+        elif EDIT_MODE() == editorstate.SLIDE_TRIM:
+            _slide_trim_left(delta)
+    elif delta > 0:
+        if EDIT_MODE() == editorstate.ONE_ROLL_TRIM:
+            _one_roll_trim_right(delta)
+        elif EDIT_MODE() == editorstate.TWO_ROLL_TRIM:
+            _tworoll_trim_right(delta)
+        elif EDIT_MODE() == editorstate.SLIDE_TRIM:
+            _slide_trim_right(delta)
+
 def left_arrow_pressed(ctrl_pressed):
     global submode
     if submode == MOUSE_EDIT_ON:
@@ -508,14 +542,17 @@ def set_oneroll_mode(track, current_frame=-1, editing_to_clip=None):
     else:
         current_sequence().display_trim_clip(None, clip_start, clip.create_data, None) # pattern producer
 
-    PLAYER().seek_frame(edit_frame)
+    if edit_data["to_side_being_edited"] == False and gui.monitor_widget.is_active(True) == True:
+        fix_delta = -1
+    else:
+        fix_delta = 0
+    
+    PLAYER().seek_frame(edit_frame + fix_delta)
     return True
 
 def oneroll_trim_press(event, frame, x=None, y=None):
     """
     User presses mouse when in one roll mode.
-    
-    WE ARE HITTING THIS FROM MULTITRIM ONLY, NOT TRIM TOOL because we remove non-quick enter edits.
     """
     global mouse_disabled, submode
     
