@@ -90,7 +90,8 @@ class LaunchThread(threading.Thread):
         
     def run(self):
         self.callback(self.data)
-        
+
+
 # -------------------------------- UTIL FUNCTIONS
 def fps():
     return editorstate.PROJECT().profile.fps()
@@ -189,6 +190,66 @@ def get_tc_string_with_fps(frame, frames_per_sec):
     mins = mins % 60
     return "%02d:%02d:%02d:%02d" % (hours, mins, sec, fr)
 
+def get_tc_zeros_overlay(frame):
+    return get_tc_zeros_overlay_string_with_fps_v2(frame, fps())
+
+def get_tc_zeros_overlay_fine_grained(frame):
+    return get_tc_zeros_overlay_string_with_fps(frame, fps())
+    
+def get_tc_zeros_overlay_string_with_fps(frame, frames_per_sec):
+    # convert fractional frame rates (like 23.976) into integers,
+    # otherwise the timeline will slowly drift over time
+    frames_per_sec = int(round(frames_per_sec))
+
+    fr = frame % frames_per_sec
+    sec = frame // frames_per_sec
+    mins = sec // 60
+    sec = sec % 60
+    hours = mins // 60
+    mins = mins % 60
+
+    if hours > 9:
+        return ""
+    elif hours > 0:
+        return "0"
+    elif hours == 0 and mins > 9:
+        return "00:"
+    elif mins > 0:
+        return "00:0"
+    elif sec > 9:
+        return "00:00:"
+    elif sec > 0:
+        return "00:00:0"
+    elif fr > 9:
+        return "00:00:00:"
+    elif fr > 0:
+        return "00:00:00:0"
+    else:
+        return "00:00:00:00"
+
+def get_tc_zeros_overlay_string_with_fps_v2(frame, frames_per_sec):
+    # convert fractional frame rates (like 23.976) into integers,
+    # otherwise the timeline will slowly drift over time
+    frames_per_sec = int(round(frames_per_sec))
+
+    fr = frame % frames_per_sec
+    sec = frame // frames_per_sec
+    mins = sec // 60
+    sec = sec % 60
+    hours = mins // 60
+    mins = mins % 60
+
+    if hours > 0:
+        return ""
+    elif mins > 0:
+        return "00:"
+    elif sec > 0:
+        return "00:00:"
+    elif fr > 0:
+        return "00:00:00:"
+    else:
+        return "00:00:00:00"
+        
 def get_tc_string_with_fps_for_filename(frame, frames_per_sec):
     frames_per_sec = int(round(frames_per_sec))
 
@@ -199,7 +260,7 @@ def get_tc_string_with_fps_for_filename(frame, frames_per_sec):
     hours = mins / 60
     mins = mins % 60
     return "%02d-%02d-%02d-%02d" % (hours, mins, sec, fr)
-    
+
 def get_time_str_for_sec_float(sec):
     mins = sec / 60
     sec = sec % 60
@@ -387,7 +448,7 @@ def get_file_producer_info(file_producer):
     info = {}
     info["width"] = clip.get_int("width")
     info["height"] = clip.get_int("height")
-    info["length"]  = clip.get_length()
+    info["length"] = clip.get_length()
     
     video_index = clip.get_int("video_index")
     audio_index = clip.get_int("audio_index")
@@ -395,7 +456,9 @@ def get_file_producer_info(file_producer):
     long_audio_property = "meta.media." + str(audio_index) + ".codec.long_name"
     sample_rate_property = "meta.media." + str(audio_index) + ".codec.sample_rate"
     channels_property = "meta.media." + str(audio_index) +  ".codec.channels"
-    
+    pix_ftm_property = "meta.media." + str(video_index) + ".codec.pix_fmt"
+    color_space_property = "meta.media." + str(video_index) + ".codec.colorspace"
+
     info["vcodec"] = clip.get(str(long_video_property))
     info["acodec"] = clip.get(str(long_audio_property))
     info["channels"] = clip.get_int(str(channels_property))
@@ -405,7 +468,9 @@ def get_file_producer_info(file_producer):
     info["fps_den"] = frame.get_double("meta.media.frame_rate_den")
     info["progressive"] = frame.get_int("meta.media.progressive") == 1
     info["top_field_first"] = frame.get_int("meta.media.top_field_first") == 1
-    
+    info["pixel_format"] = clip.get(str(pix_ftm_property))
+    info["colorspace"] = clip.get(str(color_space_property))
+
     resource = clip.get("resource")
     name, ext = os.path.splitext(resource)
     ext = ext.lstrip(".")
@@ -453,7 +518,7 @@ def program_is_installed(program):
 
     return False
     
-# File exntension lists
+# File extension lists
 _audio_file_extensions = [  "act",
                             "aif",
                             "aiff",
