@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2012 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -91,9 +91,9 @@ class EditPoint:
             and (test_x <= self.x + EDIT_POINT_SIDE_HALF  * side_mult) 
             and (test_y >= self.y - EDIT_POINT_SIDE_HALF * side_mult)
             and (test_y <= self.y + EDIT_POINT_SIDE_HALF * side_mult)):
-            return True;
+            return True
 
-        return False;
+        return False
 
     def draw(self, cr, view_editor):
         if self.display_type == INVISIBLE_POINT:
@@ -213,11 +213,11 @@ class EditPointShape:
             if px < x_low:
                 x_low = p.x
             if px > x_high:
-                x_high = p.x;
+                x_high = p.x
             if py < y_low:
-                y_low = p.y;
+                y_low = p.y
             if py > y_high:
-                y_high = p.y;
+                y_high = p.y
 
         return (x_low, y_low, x_high - x_low, y_high - y_low)
 
@@ -320,7 +320,7 @@ class SimpleRectEditShape(EditPointShape):
 
     def get_handle_guides(self, hit_point):
         index = self.edit_points.index(hit_point)
-        opp_handle_index = (index + 2) % 4;
+        opp_handle_index = (index + 2) % 4
         opp_handle = self.edit_points[opp_handle_index]
 
         guide_1_handle = self.edit_points[(opp_handle_index - 1) % 4]
@@ -357,7 +357,7 @@ class RotoMaskEditShape(EditPointShape):
         self.view_editor = view_editor # This is viewEditor.ViewEditor
         self.rotomask_editor = rotomask_editor
         
-        keyframe, bz_points = clip_editor.keyframes[0]
+        keyframe, bz_points, kf_type = clip_editor.keyframes[0]
         if len(bz_points) > 2:
             self.closed = True
         else:
@@ -391,7 +391,7 @@ class RotoMaskEditShape(EditPointShape):
                 self.view_editor.panel_coord_to_normalized_movie_coord(hp2)]
 
         for kf_tuple in self.clip_editor.keyframes:
-            keyframe, bz_points = kf_tuple
+            keyframe, bz_points, kf_type = kf_tuple
             bz_points.insert(index, hch) 
 
     def delete_selected_point(self):
@@ -399,7 +399,7 @@ class RotoMaskEditShape(EditPointShape):
             return
 
         for kf_tuple in self.clip_editor.keyframes:
-            keyframe, bz_points = kf_tuple
+            keyframe, bz_points, kf_type = kf_tuple
             bz_points.pop(self.selected_point_index) 
         
         self.selected_point_array = None
@@ -583,7 +583,7 @@ class RotoMaskEditShape(EditPointShape):
         return (back.end_point, forward.end_point)
 
     def save_selected_point_data(self, selected_point):
-        # These points get re-created all the time and we need to save data on which point was selectes
+        # These points get re-created all the time and we need to save data on which point was selects
         if selected_point in self.curve_points:
             self.selected_point_array = self.curve_points
             self.selected_point_index = self.curve_points.index(selected_point)
@@ -623,25 +623,25 @@ class RotoMaskEditShape(EditPointShape):
         
         # If single keyframe, just return values of that 
         if len(keyframes) < 2:
-            keyframe, bz_points = keyframes[0]
+            keyframe, bz_points, kf_type = keyframes[0]
             return bz_points
 
         # if current_frame after last keyframe, use last kayframe for values, no continued interpolation
         last_keyframe = 0
         for kf_tuple in self.clip_editor.keyframes:
-            keyframe, bz_points = kf_tuple
+            keyframe, bz_points, kf_type = kf_tuple
             if keyframe > last_keyframe:
                 last_keyframe = keyframe
         
         # More of the last keyframe value fix, code below this block isn't getting the value for last kf and frames after that right
-        l_keyframe, l_bz_points = self.clip_editor.keyframes[-1]       
+        l_keyframe, l_bz_points, kf_type = self.clip_editor.keyframes[-1]       
         if current_frame >= last_keyframe:
             return l_bz_points
         
         # Get keyframe range containing current_frame
         for i in range(0, len(keyframes) - 1):
-            keyframe, bz_points = keyframes[i]
-            keyframe_next, bz_points2 = keyframes[i + 1] # were quaranteed to have at least 2 keyframes when getting here
+            keyframe, bz_points, kf_type = keyframes[i]
+            keyframe_next, bz_points2, kf_type = keyframes[i + 1] # were quaranteed to have at least 2 keyframes when getting here
             if current_frame >= keyframe and current_frame < keyframe_next:
                 break
         
@@ -668,8 +668,8 @@ class RotoMaskEditShape(EditPointShape):
     def lerp(self, pa, pb, t):
         pax, pay = pa
         pbx, pby = pb
-        x = pax + ( pbx - pax ) * t;
-        y = pay + ( pby - pay ) * t;
+        x = pax + ( pbx - pax ) * t
+        y = pay + ( pby - pay ) * t
         return (x, y)
     
     def draw_line_shape(self, cr, view_editor):
@@ -715,7 +715,6 @@ class RotoMaskEditShape(EditPointShape):
 
     # ------------------------------------------------------------- saving edits
     def convert_shape_coords_and_update_clip_editor_keyframes(self):
-        clip_editor_keyframes = []
         frame_shape = self._get_converted_frame_shape()
         self.clip_editor.set_active_kf_value(frame_shape)
      
@@ -740,6 +739,3 @@ class RotoMaskEditShape(EditPointShape):
         nx, ny = np
         return [nx, ny]
 
-        
-        
-        
